/****************************************************************************
** Meta object code from reading C++ file 'native_adaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../lxqt-globalkeys-2.3.0/daemon/native_adaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'native_adaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.10.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13NativeAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto NativeAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN13NativeAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NativeAdaptor",
        "onAddClientAction",
        "",
        "std::pair<QString,qulonglong>&",
        "QDBusObjectPath",
        "onModifyClientAction",
        "qulonglong&",
        "onChangeClientActionShortcut",
        "onRemoveClientAction",
        "bool&",
        "onDeactivateClientAction",
        "onEnableClientAction",
        "onIsClientActionEnabled",
        "onGrabShortcut",
        "QString&",
        "QDBusMessage",
        "onCancelShortcutGrab"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'onAddClientAction'
        QtMocHelpers::SignalData<void(QPair<QString,qulonglong> &, const QString &, const QDBusObjectPath &, const QString &, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::QString, 2 }, { 0x80000000 | 4, 2 }, { QMetaType::QString, 2 },
            { QMetaType::QString, 2 },
        }}),
        // Signal 'onModifyClientAction'
        QtMocHelpers::SignalData<void(qulonglong &, const QDBusObjectPath &, const QString &, const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 }, { 0x80000000 | 4, 2 }, { QMetaType::QString, 2 }, { QMetaType::QString, 2 },
        }}),
        // Signal 'onChangeClientActionShortcut'
        QtMocHelpers::SignalData<void(QPair<QString,qulonglong> &, const QDBusObjectPath &, const QString &, const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 4, 2 }, { QMetaType::QString, 2 }, { QMetaType::QString, 2 },
        }}),
        // Signal 'onRemoveClientAction'
        QtMocHelpers::SignalData<void(bool &, const QDBusObjectPath &, const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 }, { 0x80000000 | 4, 2 }, { QMetaType::QString, 2 },
        }}),
        // Signal 'onDeactivateClientAction'
        QtMocHelpers::SignalData<void(bool &, const QDBusObjectPath &, const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 }, { 0x80000000 | 4, 2 }, { QMetaType::QString, 2 },
        }}),
        // Signal 'onEnableClientAction'
        QtMocHelpers::SignalData<void(bool &, const QDBusObjectPath &, bool, const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 }, { 0x80000000 | 4, 2 }, { QMetaType::Bool, 2 }, { QMetaType::QString, 2 },
        }}),
        // Signal 'onIsClientActionEnabled'
        QtMocHelpers::SignalData<void(bool &, const QDBusObjectPath &, const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 }, { 0x80000000 | 4, 2 }, { QMetaType::QString, 2 },
        }}),
        // Signal 'onGrabShortcut'
        QtMocHelpers::SignalData<void(uint, QString &, bool &, bool &, bool &, const QDBusMessage &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 2 }, { 0x80000000 | 14, 2 }, { 0x80000000 | 9, 2 }, { 0x80000000 | 9, 2 },
            { 0x80000000 | 9, 2 }, { 0x80000000 | 15, 2 },
        }}),
        // Signal 'onCancelShortcutGrab'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NativeAdaptor, qt_meta_tag_ZN13NativeAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject NativeAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13NativeAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13NativeAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13NativeAdaptorE_t>.metaTypes,
    nullptr
} };

void NativeAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NativeAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->onAddClientAction((*reinterpret_cast<std::add_pointer_t<std::pair<QString,qulonglong>&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5]))); break;
        case 1: _t->onModifyClientAction((*reinterpret_cast<std::add_pointer_t<qulonglong&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 2: _t->onChangeClientActionShortcut((*reinterpret_cast<std::add_pointer_t<std::pair<QString,qulonglong>&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 3: _t->onRemoveClientAction((*reinterpret_cast<std::add_pointer_t<bool&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 4: _t->onDeactivateClientAction((*reinterpret_cast<std::add_pointer_t<bool&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 5: _t->onEnableClientAction((*reinterpret_cast<std::add_pointer_t<bool&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 6: _t->onIsClientActionEnabled((*reinterpret_cast<std::add_pointer_t<bool&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 7: _t->onGrabShortcut((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[6]))); break;
        case 8: _t->onCancelShortcutGrab(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NativeAdaptor::*)(QPair<QString,qulonglong> & , const QString & , const QDBusObjectPath & , const QString & , const QString & )>(_a, &NativeAdaptor::onAddClientAction, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NativeAdaptor::*)(qulonglong & , const QDBusObjectPath & , const QString & , const QString & )>(_a, &NativeAdaptor::onModifyClientAction, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NativeAdaptor::*)(QPair<QString,qulonglong> & , const QDBusObjectPath & , const QString & , const QString & )>(_a, &NativeAdaptor::onChangeClientActionShortcut, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (NativeAdaptor::*)(bool & , const QDBusObjectPath & , const QString & )>(_a, &NativeAdaptor::onRemoveClientAction, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (NativeAdaptor::*)(bool & , const QDBusObjectPath & , const QString & )>(_a, &NativeAdaptor::onDeactivateClientAction, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (NativeAdaptor::*)(bool & , const QDBusObjectPath & , bool , const QString & )>(_a, &NativeAdaptor::onEnableClientAction, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (NativeAdaptor::*)(bool & , const QDBusObjectPath & , const QString & )>(_a, &NativeAdaptor::onIsClientActionEnabled, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (NativeAdaptor::*)(uint , QString & , bool & , bool & , bool & , const QDBusMessage & )>(_a, &NativeAdaptor::onGrabShortcut, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (NativeAdaptor::*)()>(_a, &NativeAdaptor::onCancelShortcutGrab, 8))
            return;
    }
}

const QMetaObject *NativeAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NativeAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13NativeAdaptorE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return QObject::qt_metacast(_clname);
}

int NativeAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void NativeAdaptor::onAddClientAction(QPair<QString,qulonglong> & _t1, const QString & _t2, const QDBusObjectPath & _t3, const QString & _t4, const QString & _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 1
void NativeAdaptor::onModifyClientAction(qulonglong & _t1, const QDBusObjectPath & _t2, const QString & _t3, const QString & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 2
void NativeAdaptor::onChangeClientActionShortcut(QPair<QString,qulonglong> & _t1, const QDBusObjectPath & _t2, const QString & _t3, const QString & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 3
void NativeAdaptor::onRemoveClientAction(bool & _t1, const QDBusObjectPath & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void NativeAdaptor::onDeactivateClientAction(bool & _t1, const QDBusObjectPath & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3);
}

// SIGNAL 5
void NativeAdaptor::onEnableClientAction(bool & _t1, const QDBusObjectPath & _t2, bool _t3, const QString & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 6
void NativeAdaptor::onIsClientActionEnabled(bool & _t1, const QDBusObjectPath & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2, _t3);
}

// SIGNAL 7
void NativeAdaptor::onGrabShortcut(uint _t1, QString & _t2, bool & _t3, bool & _t4, bool & _t5, const QDBusMessage & _t6)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2, _t3, _t4, _t5, _t6);
}

// SIGNAL 8
void NativeAdaptor::onCancelShortcutGrab()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
