/****************************************************************************
** Meta object code from reading C++ file 'org.lxqt.global_key_shortcuts.daemon.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "org.lxqt.global_key_shortcuts.daemon.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'org.lxqt.global_key_shortcuts.daemon.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.10.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN42OrgLxqtGlobal_key_shortcutsDaemonInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgLxqtGlobal_key_shortcutsDaemonInterface::qt_create_metaobjectdata<qt_meta_tag_ZN42OrgLxqtGlobal_key_shortcutsDaemonInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgLxqtGlobal_key_shortcutsDaemonInterface",
        "actionAdded",
        "",
        "id",
        "actionEnabled",
        "enabled",
        "actionModified",
        "actionRemoved",
        "actionShortcutChanged",
        "actionsSwapped",
        "id1",
        "id2",
        "clientActionSenderChanged",
        "sender",
        "multipleActionsBehaviourChanged",
        "behaviour",
        "addCommandAction",
        "QDBusPendingReply<QString,qulonglong>",
        "shortcut",
        "command",
        "arguments",
        "description",
        "QDBusReply<QString>",
        "qulonglong&",
        "addMethodAction",
        "service",
        "QDBusObjectPath",
        "path",
        "interface",
        "method",
        "cancelShortcutGrab",
        "QDBusPendingReply<>",
        "changeShortcut",
        "QDBusPendingReply<QString>",
        "enableAction",
        "QDBusPendingReply<bool>",
        "getActionById",
        "QDBusPendingReply<bool,QString,QString,bool,QString,QString>",
        "QDBusReply<bool>",
        "QString&",
        "bool&",
        "type",
        "info",
        "getAllActionIds",
        "QDBusPendingReply<QList<qulonglong>>",
        "getAllActions",
        "QDBusPendingReply<QMap_qulonglong_GeneralActionInfo>",
        "getClientActionInfoById",
        "QDBusPendingReply<bool,QString,QString,bool,QDBusObjectPath>",
        "QDBusObjectPath&",
        "getClientActionSender",
        "getCommandActionInfoById",
        "QDBusPendingReply<bool,QString,QString,bool,QString,QStringList>",
        "QStringList&",
        "getMethodActionInfoById",
        "QDBusPendingReply<bool,QString,QString,bool,QString,QDBusObjectPat"
        "h,QString,QString>",
        "getMultipleActionsBehaviour",
        "QDBusPendingReply<uint>",
        "grabShortcut",
        "QDBusPendingReply<QString,bool,bool,bool>",
        "timeout",
        "failed",
        "cancelled",
        "timedout",
        "isActionEnabled",
        "modifyActionDescription",
        "modifyCommandAction",
        "modifyMethodAction",
        "quit",
        "Q_NOREPLY",
        "removeAction",
        "setMultipleActionsBehaviour",
        "swapActions"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'actionAdded'
        QtMocHelpers::SignalData<void(qulonglong)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 },
        }}),
        // Signal 'actionEnabled'
        QtMocHelpers::SignalData<void(qulonglong, bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { QMetaType::Bool, 5 },
        }}),
        // Signal 'actionModified'
        QtMocHelpers::SignalData<void(qulonglong)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 },
        }}),
        // Signal 'actionRemoved'
        QtMocHelpers::SignalData<void(qulonglong)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 },
        }}),
        // Signal 'actionShortcutChanged'
        QtMocHelpers::SignalData<void(qulonglong)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 },
        }}),
        // Signal 'actionsSwapped'
        QtMocHelpers::SignalData<void(qulonglong, qulonglong)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 10 }, { QMetaType::ULongLong, 11 },
        }}),
        // Signal 'clientActionSenderChanged'
        QtMocHelpers::SignalData<void(qulonglong, const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { QMetaType::QString, 13 },
        }}),
        // Signal 'multipleActionsBehaviourChanged'
        QtMocHelpers::SignalData<void(uint)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 15 },
        }}),
        // Slot 'addCommandAction'
        QtMocHelpers::SlotData<QDBusPendingReply<QString,qulonglong>(const QString &, const QString &, const QStringList &, const QString &)>(16, 2, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 19 }, { QMetaType::QStringList, 20 }, { QMetaType::QString, 21 },
        }}),
        // Slot 'addCommandAction'
        QtMocHelpers::SlotData<QDBusReply<QString>(const QString &, const QString &, const QStringList &, const QString &, qulonglong &)>(16, 2, QMC::AccessPublic, 0x80000000 | 22, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 19 }, { QMetaType::QStringList, 20 }, { QMetaType::QString, 21 },
            { 0x80000000 | 23, 3 },
        }}),
        // Slot 'addMethodAction'
        QtMocHelpers::SlotData<QDBusPendingReply<QString,qulonglong>(const QString &, const QString &, const QDBusObjectPath &, const QString &, const QString &, const QString &)>(24, 2, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 25 }, { 0x80000000 | 26, 27 }, { QMetaType::QString, 28 },
            { QMetaType::QString, 29 }, { QMetaType::QString, 21 },
        }}),
        // Slot 'addMethodAction'
        QtMocHelpers::SlotData<QDBusReply<QString>(const QString &, const QString &, const QDBusObjectPath &, const QString &, const QString &, const QString &, qulonglong &)>(24, 2, QMC::AccessPublic, 0x80000000 | 22, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 25 }, { 0x80000000 | 26, 27 }, { QMetaType::QString, 28 },
            { QMetaType::QString, 29 }, { QMetaType::QString, 21 }, { 0x80000000 | 23, 3 },
        }}),
        // Slot 'cancelShortcutGrab'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(30, 2, QMC::AccessPublic, 0x80000000 | 31),
        // Slot 'changeShortcut'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(qulonglong, const QString &)>(32, 2, QMC::AccessPublic, 0x80000000 | 33, {{
            { QMetaType::ULongLong, 3 }, { QMetaType::QString, 18 },
        }}),
        // Slot 'enableAction'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(qulonglong, bool)>(34, 2, QMC::AccessPublic, 0x80000000 | 35, {{
            { QMetaType::ULongLong, 3 }, { QMetaType::Bool, 5 },
        }}),
        // Slot 'getActionById'
        QtMocHelpers::SlotData<QDBusPendingReply<bool,QString,QString,bool,QString,QString>(qulonglong)>(36, 2, QMC::AccessPublic, 0x80000000 | 37, {{
            { QMetaType::ULongLong, 3 },
        }}),
        // Slot 'getActionById'
        QtMocHelpers::SlotData<QDBusReply<bool>(qulonglong, QString &, QString &, bool &, QString &, QString &)>(36, 2, QMC::AccessPublic, 0x80000000 | 38, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 39, 18 }, { 0x80000000 | 39, 21 }, { 0x80000000 | 40, 5 },
            { 0x80000000 | 39, 41 }, { 0x80000000 | 39, 42 },
        }}),
        // Slot 'getAllActionIds'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<qulonglong> >()>(43, 2, QMC::AccessPublic, 0x80000000 | 44),
        // Slot 'getAllActions'
        QtMocHelpers::SlotData<QDBusPendingReply<QMap_qulonglong_GeneralActionInfo>()>(45, 2, QMC::AccessPublic, 0x80000000 | 46),
        // Slot 'getClientActionInfoById'
        QtMocHelpers::SlotData<QDBusPendingReply<bool,QString,QString,bool,QDBusObjectPath>(qulonglong)>(47, 2, QMC::AccessPublic, 0x80000000 | 48, {{
            { QMetaType::ULongLong, 3 },
        }}),
        // Slot 'getClientActionInfoById'
        QtMocHelpers::SlotData<QDBusReply<bool>(qulonglong, QString &, QString &, bool &, QDBusObjectPath &)>(47, 2, QMC::AccessPublic, 0x80000000 | 38, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 39, 18 }, { 0x80000000 | 39, 21 }, { 0x80000000 | 40, 5 },
            { 0x80000000 | 49, 27 },
        }}),
        // Slot 'getClientActionSender'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(qulonglong)>(50, 2, QMC::AccessPublic, 0x80000000 | 33, {{
            { QMetaType::ULongLong, 3 },
        }}),
        // Slot 'getCommandActionInfoById'
        QtMocHelpers::SlotData<QDBusPendingReply<bool,QString,QString,bool,QString,QStringList>(qulonglong)>(51, 2, QMC::AccessPublic, 0x80000000 | 52, {{
            { QMetaType::ULongLong, 3 },
        }}),
        // Slot 'getCommandActionInfoById'
        QtMocHelpers::SlotData<QDBusReply<bool>(qulonglong, QString &, QString &, bool &, QString &, QStringList &)>(51, 2, QMC::AccessPublic, 0x80000000 | 38, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 39, 18 }, { 0x80000000 | 39, 21 }, { 0x80000000 | 40, 5 },
            { 0x80000000 | 39, 19 }, { 0x80000000 | 53, 20 },
        }}),
        // Slot 'getMethodActionInfoById'
        QtMocHelpers::SlotData<QDBusPendingReply<bool,QString,QString,bool,QString,QDBusObjectPath,QString,QString>(qulonglong)>(54, 2, QMC::AccessPublic, 0x80000000 | 55, {{
            { QMetaType::ULongLong, 3 },
        }}),
        // Slot 'getMethodActionInfoById'
        QtMocHelpers::SlotData<QDBusReply<bool>(qulonglong, QString &, QString &, bool &, QString &, QDBusObjectPath &, QString &, QString &)>(54, 2, QMC::AccessPublic, 0x80000000 | 38, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 39, 18 }, { 0x80000000 | 39, 21 }, { 0x80000000 | 40, 5 },
            { 0x80000000 | 39, 25 }, { 0x80000000 | 49, 27 }, { 0x80000000 | 39, 28 }, { 0x80000000 | 39, 29 },
        }}),
        // Slot 'getMultipleActionsBehaviour'
        QtMocHelpers::SlotData<QDBusPendingReply<uint>()>(56, 2, QMC::AccessPublic, 0x80000000 | 57),
        // Slot 'grabShortcut'
        QtMocHelpers::SlotData<QDBusPendingReply<QString,bool,bool,bool>(uint)>(58, 2, QMC::AccessPublic, 0x80000000 | 59, {{
            { QMetaType::UInt, 60 },
        }}),
        // Slot 'grabShortcut'
        QtMocHelpers::SlotData<QDBusReply<QString>(uint, bool &, bool &, bool &)>(58, 2, QMC::AccessPublic, 0x80000000 | 22, {{
            { QMetaType::UInt, 60 }, { 0x80000000 | 40, 61 }, { 0x80000000 | 40, 62 }, { 0x80000000 | 40, 63 },
        }}),
        // Slot 'isActionEnabled'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(qulonglong)>(64, 2, QMC::AccessPublic, 0x80000000 | 35, {{
            { QMetaType::ULongLong, 3 },
        }}),
        // Slot 'modifyActionDescription'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(qulonglong, const QString &)>(65, 2, QMC::AccessPublic, 0x80000000 | 35, {{
            { QMetaType::ULongLong, 3 }, { QMetaType::QString, 21 },
        }}),
        // Slot 'modifyCommandAction'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(qulonglong, const QString &, const QStringList &, const QString &)>(66, 2, QMC::AccessPublic, 0x80000000 | 35, {{
            { QMetaType::ULongLong, 3 }, { QMetaType::QString, 19 }, { QMetaType::QStringList, 20 }, { QMetaType::QString, 21 },
        }}),
        // Slot 'modifyMethodAction'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(qulonglong, const QString &, const QDBusObjectPath &, const QString &, const QString &, const QString &)>(67, 2, QMC::AccessPublic, 0x80000000 | 35, {{
            { QMetaType::ULongLong, 3 }, { QMetaType::QString, 25 }, { 0x80000000 | 26, 27 }, { QMetaType::QString, 28 },
            { QMetaType::QString, 29 }, { QMetaType::QString, 21 },
        }}),
        // Slot 'quit'
        QtMocHelpers::SlotData<void()>(68, 69, QMC::AccessPublic, QMetaType::Void),
        // Slot 'removeAction'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(qulonglong)>(70, 2, QMC::AccessPublic, 0x80000000 | 35, {{
            { QMetaType::ULongLong, 3 },
        }}),
        // Slot 'setMultipleActionsBehaviour'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(uint)>(71, 2, QMC::AccessPublic, 0x80000000 | 35, {{
            { QMetaType::UInt, 15 },
        }}),
        // Slot 'swapActions'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(qulonglong, qulonglong)>(72, 2, QMC::AccessPublic, 0x80000000 | 35, {{
            { QMetaType::ULongLong, 10 }, { QMetaType::ULongLong, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgLxqtGlobal_key_shortcutsDaemonInterface, qt_meta_tag_ZN42OrgLxqtGlobal_key_shortcutsDaemonInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgLxqtGlobal_key_shortcutsDaemonInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN42OrgLxqtGlobal_key_shortcutsDaemonInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN42OrgLxqtGlobal_key_shortcutsDaemonInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN42OrgLxqtGlobal_key_shortcutsDaemonInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgLxqtGlobal_key_shortcutsDaemonInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgLxqtGlobal_key_shortcutsDaemonInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->actionAdded((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 1: _t->actionEnabled((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 2: _t->actionModified((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 3: _t->actionRemoved((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 4: _t->actionShortcutChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 5: _t->actionsSwapped((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2]))); break;
        case 6: _t->clientActionSenderChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 7: _t->multipleActionsBehaviourChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 8: { QDBusPendingReply<QString,qulonglong> _r = _t->addCommandAction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString,qulonglong>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusReply<QString> _r = _t->addCommandAction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<qulonglong&>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QDBusReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<QString,qulonglong> _r = _t->addMethodAction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString,qulonglong>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusReply<QString> _r = _t->addMethodAction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<qulonglong&>>(_a[7])));
            if (_a[0]) *reinterpret_cast<QDBusReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<> _r = _t->cancelShortcutGrab();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<QString> _r = _t->changeShortcut((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<bool> _r = _t->enableAction((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QDBusPendingReply<bool,QString,QString,bool,QString,QString> _r = _t->getActionById((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool,QString,QString,bool,QString,QString>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QDBusReply<bool> _r = _t->getActionById((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QDBusReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusPendingReply<QList<qulonglong>> _r = _t->getAllActionIds();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<qulonglong>>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QDBusPendingReply<QMap_qulonglong_GeneralActionInfo> _r = _t->getAllActions();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QMap_qulonglong_GeneralActionInfo>*>(_a[0]) = std::move(_r); }  break;
        case 19: { QDBusPendingReply<bool,QString,QString,bool,QDBusObjectPath> _r = _t->getClientActionInfoById((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool,QString,QString,bool,QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 20: { QDBusReply<bool> _r = _t->getClientActionInfoById((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath&>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QDBusReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 21: { QDBusPendingReply<QString> _r = _t->getClientActionSender((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 22: { QDBusPendingReply<bool,QString,QString,bool,QString,QStringList> _r = _t->getCommandActionInfoById((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool,QString,QString,bool,QString,QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 23: { QDBusReply<bool> _r = _t->getCommandActionInfoById((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QStringList&>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QDBusReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 24: { QDBusPendingReply<bool,QString,QString,bool,QString,QDBusObjectPath,QString,QString> _r = _t->getMethodActionInfoById((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool,QString,QString,bool,QString,QDBusObjectPath,QString,QString>*>(_a[0]) = std::move(_r); }  break;
        case 25: { QDBusReply<bool> _r = _t->getMethodActionInfoById((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath&>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[8])));
            if (_a[0]) *reinterpret_cast<QDBusReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 26: { QDBusPendingReply<uint> _r = _t->getMultipleActionsBehaviour();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<uint>*>(_a[0]) = std::move(_r); }  break;
        case 27: { QDBusPendingReply<QString,bool,bool,bool> _r = _t->grabShortcut((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString,bool,bool,bool>*>(_a[0]) = std::move(_r); }  break;
        case 28: { QDBusReply<QString> _r = _t->grabShortcut((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 29: { QDBusPendingReply<bool> _r = _t->isActionEnabled((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 30: { QDBusPendingReply<bool> _r = _t->modifyActionDescription((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 31: { QDBusPendingReply<bool> _r = _t->modifyCommandAction((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 32: { QDBusPendingReply<bool> _r = _t->modifyMethodAction((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 33: _t->quit(); break;
        case 34: { QDBusPendingReply<bool> _r = _t->removeAction((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 35: { QDBusPendingReply<bool> _r = _t->setMultipleActionsBehaviour((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 36: { QDBusPendingReply<bool> _r = _t->swapActions((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgLxqtGlobal_key_shortcutsDaemonInterface::*)(qulonglong )>(_a, &OrgLxqtGlobal_key_shortcutsDaemonInterface::actionAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgLxqtGlobal_key_shortcutsDaemonInterface::*)(qulonglong , bool )>(_a, &OrgLxqtGlobal_key_shortcutsDaemonInterface::actionEnabled, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgLxqtGlobal_key_shortcutsDaemonInterface::*)(qulonglong )>(_a, &OrgLxqtGlobal_key_shortcutsDaemonInterface::actionModified, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgLxqtGlobal_key_shortcutsDaemonInterface::*)(qulonglong )>(_a, &OrgLxqtGlobal_key_shortcutsDaemonInterface::actionRemoved, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgLxqtGlobal_key_shortcutsDaemonInterface::*)(qulonglong )>(_a, &OrgLxqtGlobal_key_shortcutsDaemonInterface::actionShortcutChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgLxqtGlobal_key_shortcutsDaemonInterface::*)(qulonglong , qulonglong )>(_a, &OrgLxqtGlobal_key_shortcutsDaemonInterface::actionsSwapped, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgLxqtGlobal_key_shortcutsDaemonInterface::*)(qulonglong , const QString & )>(_a, &OrgLxqtGlobal_key_shortcutsDaemonInterface::clientActionSenderChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgLxqtGlobal_key_shortcutsDaemonInterface::*)(uint )>(_a, &OrgLxqtGlobal_key_shortcutsDaemonInterface::multipleActionsBehaviourChanged, 7))
            return;
    }
}

const QMetaObject *OrgLxqtGlobal_key_shortcutsDaemonInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgLxqtGlobal_key_shortcutsDaemonInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN42OrgLxqtGlobal_key_shortcutsDaemonInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgLxqtGlobal_key_shortcutsDaemonInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 37)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 37;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 37)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 37;
    }
    return _id;
}

// SIGNAL 0
void OrgLxqtGlobal_key_shortcutsDaemonInterface::actionAdded(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void OrgLxqtGlobal_key_shortcutsDaemonInterface::actionEnabled(qulonglong _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void OrgLxqtGlobal_key_shortcutsDaemonInterface::actionModified(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void OrgLxqtGlobal_key_shortcutsDaemonInterface::actionRemoved(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void OrgLxqtGlobal_key_shortcutsDaemonInterface::actionShortcutChanged(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void OrgLxqtGlobal_key_shortcutsDaemonInterface::actionsSwapped(qulonglong _t1, qulonglong _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void OrgLxqtGlobal_key_shortcutsDaemonInterface::clientActionSenderChanged(qulonglong _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void OrgLxqtGlobal_key_shortcutsDaemonInterface::multipleActionsBehaviourChanged(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
