/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.lxqt.global_key_shortcuts.client.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "org.lxqt.global_key_shortcuts.client.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class OrgLxqtActionClientAdaptor
 */

OrgLxqtActionClientAdaptor::OrgLxqtActionClientAdaptor(GlobalKeyShortcut::ActionImpl *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

OrgLxqtActionClientAdaptor::~OrgLxqtActionClientAdaptor()
{
    // destructor
}

void OrgLxqtActionClientAdaptor::activated()
{
    // handle method call org.lxqt.global_key_shortcuts.client.activated
    parent()->activated();
}

void OrgLxqtActionClientAdaptor::shortcutChanged(const QString &oldShortcut, const QString &newShortcut)
{
    // handle method call org.lxqt.global_key_shortcuts.client.shortcutChanged
    parent()->shortcutChanged(oldShortcut, newShortcut);
}


#include "moc_org.lxqt.global_key_shortcuts.client.cpp"
