/****************************************************************************
** Meta object code from reading C++ file 'org.lxqt.global_key_shortcuts.daemon.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "org.lxqt.global_key_shortcuts.daemon.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'org.lxqt.global_key_shortcuts.daemon.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.10.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN32OrgLxqtGlobalActionDaemonAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgLxqtGlobalActionDaemonAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN32OrgLxqtGlobalActionDaemonAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgLxqtGlobalActionDaemonAdaptor",
        "D-Bus Interface",
        "org.lxqt.global_key_shortcuts.daemon",
        "D-Bus Introspection",
        "  <interface name=\"org.lxqt.global_key_shortcuts.daemon\">\n    <"
        "method name=\"addMethodAction\">\n      <arg direction=\"in\" type"
        "=\"s\" name=\"shortcut\"/>\n      <arg direction=\"in\" type=\"s\""
        " name=\"service\"/>\n      <arg direction=\"in\" type=\"o\" name=\""
        "path\"/>\n      <arg direction=\"in\" type=\"s\" name=\"interface\""
        "/>\n      <arg direction=\"in\" type=\"s\" name=\"method\"/>\n    "
        "  <arg direction=\"in\" type=\"s\" name=\"description\"/>\n      <"
        "arg direction=\"out\" type=\"s\" name=\"usedShortcut\"/>\n      <a"
        "rg direction=\"out\" type=\"t\" name=\"id\"/>\n    </method>\n    "
        "<method name=\"addCommandAction\">\n      <arg direction=\"in\" ty"
        "pe=\"s\" name=\"shortcut\"/>\n      <arg direction=\"in\" type=\"s"
        "\" name=\"command\"/>\n      <arg direction=\"in\" type=\"as\" nam"
        "e=\"arguments\"/>\n      <arg direction=\"in\" type=\"s\" name=\"d"
        "escription\"/>\n      <arg direction=\"out\" type=\"s\" name=\"use"
        "dShortcut\"/>\n      <arg direction=\"out\" type=\"t\" name=\"id\""
        "/>\n    </method>\n    <signal name=\"actionAdded\">\n      <arg t"
        "ype=\"t\" name=\"id\"/>\n    </signal>\n    <method name=\"modifyA"
        "ctionDescription\">\n      <arg direction=\"in\" type=\"t\" name=\""
        "id\"/>\n      <arg direction=\"in\" type=\"s\" name=\"description\""
        "/>\n      <arg direction=\"out\" type=\"b\"/>\n    </method>\n    "
        "<method name=\"modifyMethodAction\">\n      <arg direction=\"in\" "
        "type=\"t\" name=\"id\"/>\n      <arg direction=\"in\" type=\"s\" n"
        "ame=\"service\"/>\n      <arg direction=\"in\" type=\"o\" name=\"p"
        "ath\"/>\n      <arg direction=\"in\" type=\"s\" name=\"interface\""
        "/>\n      <arg direction=\"in\" type=\"s\" name=\"method\"/>\n    "
        "  <arg direction=\"in\" type=\"s\" name=\"description\"/>\n      <"
        "arg direction=\"out\" type=\"b\"/>\n    </method>\n    <method nam"
        "e=\"modifyCommandAction\">\n      <arg direction=\"in\" type=\"t\""
        " name=\"id\"/>\n      <arg direction=\"in\" type=\"s\" name=\"comm"
        "and\"/>\n      <arg direction=\"in\" type=\"as\" name=\"arguments\""
        "/>\n      <arg direction=\"in\" type=\"s\" name=\"description\"/>\n"
        "      <arg direction=\"out\" type=\"b\"/>\n    </method>\n    <sig"
        "nal name=\"actionModified\">\n      <arg type=\"t\" name=\"id\"/>\n"
        "    </signal>\n    <method name=\"enableAction\">\n      <arg dire"
        "ction=\"in\" type=\"t\" name=\"id\"/>\n      <arg direction=\"in\""
        " type=\"b\" name=\"enabled\"/>\n      <arg direction=\"out\" type="
        "\"b\"/>\n    </method>\n    <method name=\"isActionEnabled\">\n   "
        "   <arg direction=\"in\" type=\"t\" name=\"id\"/>\n      <arg dire"
        "ction=\"out\" type=\"b\"/>\n    </method>\n    <signal name=\"acti"
        "onEnabled\">\n      <arg type=\"t\" name=\"id\"/>\n      <arg type"
        "=\"b\" name=\"enabled\"/>\n    </signal>\n    <method name=\"getCl"
        "ientActionSender\">\n      <arg direction=\"in\" type=\"t\" name=\""
        "id\"/>\n      <arg direction=\"out\" type=\"s\"/>\n    </method>\n"
        "    <signal name=\"clientActionSenderChanged\">\n      <arg type=\""
        "t\" name=\"id\"/>\n      <arg type=\"s\" name=\"sender\"/>\n    </"
        "signal>\n    <method name=\"changeShortcut\">\n      <arg directio"
        "n=\"in\" type=\"t\" name=\"id\"/>\n      <arg direction=\"in\" typ"
        "e=\"s\" name=\"shortcut\"/>\n      <arg direction=\"out\" type=\"s"
        "\" name=\"usedShortcut\"/>\n    </method>\n    <signal name=\"acti"
        "onShortcutChanged\">\n      <arg type=\"t\" name=\"id\"/>\n    </s"
        "ignal>\n    <method name=\"swapActions\">\n      <arg direction=\""
        "in\" type=\"t\" name=\"id1\"/>\n      <arg direction=\"in\" type=\""
        "t\" name=\"id2\"/>\n      <arg direction=\"out\" type=\"b\"/>\n   "
        " </method>\n    <signal name=\"actionsSwapped\">\n      <arg type="
        "\"t\" name=\"id1\"/>\n      <arg type=\"t\" name=\"id2\"/>\n    </"
        "signal>\n    <method name=\"removeAction\">\n      <arg direction="
        "\"in\" type=\"t\" name=\"id\"/>\n      <arg direction=\"out\" type"
        "=\"b\"/>\n    </method>\n    <signal name=\"actionRemoved\">\n    "
        "  <arg type=\"t\" name=\"id\"/>\n    </signal>\n    <method name=\""
        "setMultipleActionsBehaviour\">\n      <arg direction=\"in\" type=\""
        "u\" name=\"behaviour\"/>\n      <arg direction=\"out\" type=\"b\"/"
        ">\n    </method>\n    <method name=\"getMultipleActionsBehaviour\""
        ">\n      <arg direction=\"out\" type=\"u\"/>\n    </method>\n    <"
        "signal name=\"multipleActionsBehaviourChanged\">\n      <arg type="
        "\"u\" name=\"behaviour\"/>\n    </signal>\n    <method name=\"getA"
        "llActionIds\">\n      <annotation value=\"QList&lt;qulonglong&gt;\""
        " name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n      <arg direc"
        "tion=\"out\" type=\"at\"/>\n    </method>\n    <method name=\"getA"
        "ctionById\">\n      <arg direction=\"in\" type=\"t\" name=\"id\"/>"
        "\n      <arg direction=\"out\" type=\"b\"/>\n      <arg direction="
        "\"out\" type=\"s\" name=\"shortcut\"/>\n      <arg direction=\"out"
        "\" type=\"s\" name=\"description\"/>\n      <arg direction=\"out\""
        " type=\"b\" name=\"enabled\"/>\n      <arg direction=\"out\" type="
        "\"s\" name=\"type\"/>\n      <arg direction=\"out\" type=\"s\" nam"
        "e=\"info\"/>\n    </method>\n    <method name=\"getAllActions\">\n"
        "      <annotation value=\"QMap_qulonglong_GeneralActionInfo\" name"
        "=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n      <arg direction="
        "\"out\" type=\"a{t(ssbss)}\" name=\"info\"/>\n    </method>\n    <"
        "method name=\"getClientActionInfoById\">\n      <arg direction=\"i"
        "n\" type=\"t\" name=\"id\"/>\n      <arg direction=\"out\" type=\""
        "b\"/>\n      <arg direction=\"out\" type=\"s\" name=\"shortcut\"/>"
        "\n      <arg direction=\"out\" type=\"s\" name=\"description\"/>\n"
        "      <arg direction=\"out\" type=\"b\" name=\"enabled\"/>\n      "
        "<arg direction=\"out\" type=\"o\" name=\"path\"/>\n    </method>\n"
        "    <method name=\"getMethodActionInfoById\">\n      <arg directio"
        "n=\"in\" type=\"t\" name=\"id\"/>\n      <arg direction=\"out\" ty"
        "pe=\"b\"/>\n      <arg direction=\"out\" type=\"s\" name=\"shortcu"
        "t\"/>\n      <arg direction=\"out\" type=\"s\" name=\"description\""
        "/>\n      <arg direction=\"out\" type=\"b\" name=\"enabled\"/>\n  "
        "    <arg direction=\"out\" type=\"s\" name=\"service\"/>\n      <a"
        "rg direction=\"out\" type=\"o\" name=\"path\"/>\n      <arg direct"
        "ion=\"out\" type=\"s\" name=\"interface\"/>\n      <arg direction="
        "\"out\" type=\"s\" name=\"method\"/>\n    </method>\n    <method n"
        "ame=\"getCommandActionInfoById\">\n      <arg direction=\"in\" typ"
        "e=\"t\" name=\"id\"/>\n      <arg direction=\"out\" type=\"b\"/>\n"
        "      <arg direction=\"out\" type=\"s\" name=\"shortcut\"/>\n     "
        " <arg direction=\"out\" type=\"s\" name=\"description\"/>\n      <"
        "arg direction=\"out\" type=\"b\" name=\"enabled\"/>\n      <arg di"
        "rection=\"out\" type=\"s\" name=\"command\"/>\n      <arg directio"
        "n=\"out\" type=\"as\" name=\"arguments\"/>\n    </method>\n    <me"
        "thod name=\"grabShortcut\">\n      <arg direction=\"in\" type=\"u\""
        " name=\"timeout\"/>\n      <arg direction=\"out\" type=\"s\" name="
        "\"shortcut\"/>\n      <arg direction=\"out\" type=\"b\" name=\"fai"
        "led\"/>\n      <arg direction=\"out\" type=\"b\" name=\"cancelled\""
        "/>\n      <arg direction=\"out\" type=\"b\" name=\"timedout\"/>\n "
        "   </method>\n    <method name=\"cancelShortcutGrab\"/>\n    <meth"
        "od name=\"quit\">\n      <annotation value=\"true\" name=\"org.fre"
        "edesktop.DBus.Method.NoReply\"/>\n    </method>\n  </interface>\n",
        "actionAdded",
        "",
        "id",
        "actionEnabled",
        "enabled",
        "actionModified",
        "actionRemoved",
        "actionShortcutChanged",
        "actionsSwapped",
        "id1",
        "id2",
        "clientActionSenderChanged",
        "sender",
        "multipleActionsBehaviourChanged",
        "behaviour",
        "addCommandAction",
        "shortcut",
        "command",
        "arguments",
        "description",
        "qulonglong&",
        "addMethodAction",
        "service",
        "QDBusObjectPath",
        "path",
        "interface",
        "method",
        "cancelShortcutGrab",
        "changeShortcut",
        "enableAction",
        "getActionById",
        "QString&",
        "bool&",
        "type",
        "info",
        "getAllActionIds",
        "QList<qulonglong>",
        "getAllActions",
        "QMap_qulonglong_GeneralActionInfo",
        "getClientActionInfoById",
        "QDBusObjectPath&",
        "getClientActionSender",
        "getCommandActionInfoById",
        "QStringList&",
        "getMethodActionInfoById",
        "getMultipleActionsBehaviour",
        "grabShortcut",
        "timeout",
        "failed",
        "cancelled",
        "timedout",
        "isActionEnabled",
        "modifyActionDescription",
        "modifyCommandAction",
        "modifyMethodAction",
        "quit",
        "Q_NOREPLY",
        "removeAction",
        "setMultipleActionsBehaviour",
        "swapActions"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'actionAdded'
        QtMocHelpers::SignalData<void(qulonglong)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 7 },
        }}),
        // Signal 'actionEnabled'
        QtMocHelpers::SignalData<void(qulonglong, bool)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 7 }, { QMetaType::Bool, 9 },
        }}),
        // Signal 'actionModified'
        QtMocHelpers::SignalData<void(qulonglong)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 7 },
        }}),
        // Signal 'actionRemoved'
        QtMocHelpers::SignalData<void(qulonglong)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 7 },
        }}),
        // Signal 'actionShortcutChanged'
        QtMocHelpers::SignalData<void(qulonglong)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 7 },
        }}),
        // Signal 'actionsSwapped'
        QtMocHelpers::SignalData<void(qulonglong, qulonglong)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 14 }, { QMetaType::ULongLong, 15 },
        }}),
        // Signal 'clientActionSenderChanged'
        QtMocHelpers::SignalData<void(qulonglong, const QString &)>(16, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 7 }, { QMetaType::QString, 17 },
        }}),
        // Signal 'multipleActionsBehaviourChanged'
        QtMocHelpers::SignalData<void(uint)>(18, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 19 },
        }}),
        // Slot 'addCommandAction'
        QtMocHelpers::SlotData<QString(const QString &, const QString &, const QStringList &, const QString &, qulonglong &)>(20, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 21 }, { QMetaType::QString, 22 }, { QMetaType::QStringList, 23 }, { QMetaType::QString, 24 },
            { 0x80000000 | 25, 7 },
        }}),
        // Slot 'addMethodAction'
        QtMocHelpers::SlotData<QString(const QString &, const QString &, const QDBusObjectPath &, const QString &, const QString &, const QString &, qulonglong &)>(26, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 21 }, { QMetaType::QString, 27 }, { 0x80000000 | 28, 29 }, { QMetaType::QString, 30 },
            { QMetaType::QString, 31 }, { QMetaType::QString, 24 }, { 0x80000000 | 25, 7 },
        }}),
        // Slot 'cancelShortcutGrab'
        QtMocHelpers::SlotData<void()>(32, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'changeShortcut'
        QtMocHelpers::SlotData<QString(qulonglong, const QString &)>(33, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::ULongLong, 7 }, { QMetaType::QString, 21 },
        }}),
        // Slot 'enableAction'
        QtMocHelpers::SlotData<bool(qulonglong, bool)>(34, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 7 }, { QMetaType::Bool, 9 },
        }}),
        // Slot 'getActionById'
        QtMocHelpers::SlotData<bool(qulonglong, QString &, QString &, bool &, QString &, QString &)>(35, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 7 }, { 0x80000000 | 36, 21 }, { 0x80000000 | 36, 24 }, { 0x80000000 | 37, 9 },
            { 0x80000000 | 36, 38 }, { 0x80000000 | 36, 39 },
        }}),
        // Slot 'getAllActionIds'
        QtMocHelpers::SlotData<QList<qulonglong>()>(40, 6, QMC::AccessPublic, 0x80000000 | 41),
        // Slot 'getAllActions'
        QtMocHelpers::SlotData<QMap_qulonglong_GeneralActionInfo()>(42, 6, QMC::AccessPublic, 0x80000000 | 43),
        // Slot 'getClientActionInfoById'
        QtMocHelpers::SlotData<bool(qulonglong, QString &, QString &, bool &, QDBusObjectPath &)>(44, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 7 }, { 0x80000000 | 36, 21 }, { 0x80000000 | 36, 24 }, { 0x80000000 | 37, 9 },
            { 0x80000000 | 45, 29 },
        }}),
        // Slot 'getClientActionSender'
        QtMocHelpers::SlotData<QString(qulonglong)>(46, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::ULongLong, 7 },
        }}),
        // Slot 'getCommandActionInfoById'
        QtMocHelpers::SlotData<bool(qulonglong, QString &, QString &, bool &, QString &, QStringList &)>(47, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 7 }, { 0x80000000 | 36, 21 }, { 0x80000000 | 36, 24 }, { 0x80000000 | 37, 9 },
            { 0x80000000 | 36, 22 }, { 0x80000000 | 48, 23 },
        }}),
        // Slot 'getMethodActionInfoById'
        QtMocHelpers::SlotData<bool(qulonglong, QString &, QString &, bool &, QString &, QDBusObjectPath &, QString &, QString &)>(49, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 7 }, { 0x80000000 | 36, 21 }, { 0x80000000 | 36, 24 }, { 0x80000000 | 37, 9 },
            { 0x80000000 | 36, 27 }, { 0x80000000 | 45, 29 }, { 0x80000000 | 36, 30 }, { 0x80000000 | 36, 31 },
        }}),
        // Slot 'getMultipleActionsBehaviour'
        QtMocHelpers::SlotData<uint()>(50, 6, QMC::AccessPublic, QMetaType::UInt),
        // Slot 'grabShortcut'
        QtMocHelpers::SlotData<QString(uint, bool &, bool &, bool &)>(51, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::UInt, 52 }, { 0x80000000 | 37, 53 }, { 0x80000000 | 37, 54 }, { 0x80000000 | 37, 55 },
        }}),
        // Slot 'isActionEnabled'
        QtMocHelpers::SlotData<bool(qulonglong)>(56, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 7 },
        }}),
        // Slot 'modifyActionDescription'
        QtMocHelpers::SlotData<bool(qulonglong, const QString &)>(57, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 7 }, { QMetaType::QString, 24 },
        }}),
        // Slot 'modifyCommandAction'
        QtMocHelpers::SlotData<bool(qulonglong, const QString &, const QStringList &, const QString &)>(58, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 7 }, { QMetaType::QString, 22 }, { QMetaType::QStringList, 23 }, { QMetaType::QString, 24 },
        }}),
        // Slot 'modifyMethodAction'
        QtMocHelpers::SlotData<bool(qulonglong, const QString &, const QDBusObjectPath &, const QString &, const QString &, const QString &)>(59, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 7 }, { QMetaType::QString, 27 }, { 0x80000000 | 28, 29 }, { QMetaType::QString, 30 },
            { QMetaType::QString, 31 }, { QMetaType::QString, 24 },
        }}),
        // Slot 'quit'
        QtMocHelpers::SlotData<void()>(60, 61, QMC::AccessPublic, QMetaType::Void),
        // Slot 'removeAction'
        QtMocHelpers::SlotData<bool(qulonglong)>(62, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 7 },
        }}),
        // Slot 'setMultipleActionsBehaviour'
        QtMocHelpers::SlotData<bool(uint)>(63, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::UInt, 19 },
        }}),
        // Slot 'swapActions'
        QtMocHelpers::SlotData<bool(qulonglong, qulonglong)>(64, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 14 }, { QMetaType::ULongLong, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<OrgLxqtGlobalActionDaemonAdaptor, qt_meta_tag_ZN32OrgLxqtGlobalActionDaemonAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject OrgLxqtGlobalActionDaemonAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32OrgLxqtGlobalActionDaemonAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32OrgLxqtGlobalActionDaemonAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN32OrgLxqtGlobalActionDaemonAdaptorE_t>.metaTypes,
    nullptr
} };

void OrgLxqtGlobalActionDaemonAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgLxqtGlobalActionDaemonAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->actionAdded((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 1: _t->actionEnabled((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 2: _t->actionModified((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 3: _t->actionRemoved((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 4: _t->actionShortcutChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 5: _t->actionsSwapped((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2]))); break;
        case 6: _t->clientActionSenderChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 7: _t->multipleActionsBehaviourChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 8: { QString _r = _t->addCommandAction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<qulonglong&>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 9: { QString _r = _t->addMethodAction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<qulonglong&>>(_a[7])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->cancelShortcutGrab(); break;
        case 11: { QString _r = _t->changeShortcut((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->enableAction((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: { bool _r = _t->getActionById((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[6])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 14: { QList<qulonglong> _r = _t->getAllActionIds();
            if (_a[0]) *reinterpret_cast<QList<qulonglong>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QMap_qulonglong_GeneralActionInfo _r = _t->getAllActions();
            if (_a[0]) *reinterpret_cast<QMap_qulonglong_GeneralActionInfo*>(_a[0]) = std::move(_r); }  break;
        case 16: { bool _r = _t->getClientActionInfoById((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath&>>(_a[5])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { QString _r = _t->getClientActionSender((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 18: { bool _r = _t->getCommandActionInfoById((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QStringList&>>(_a[6])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 19: { bool _r = _t->getMethodActionInfoById((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath&>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[8])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 20: { uint _r = _t->getMultipleActionsBehaviour();
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 21: { QString _r = _t->grabShortcut((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 22: { bool _r = _t->isActionEnabled((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 23: { bool _r = _t->modifyActionDescription((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 24: { bool _r = _t->modifyCommandAction((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 25: { bool _r = _t->modifyMethodAction((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 26: _t->quit(); break;
        case 27: { bool _r = _t->removeAction((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 28: { bool _r = _t->setMultipleActionsBehaviour((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 29: { bool _r = _t->swapActions((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgLxqtGlobalActionDaemonAdaptor::*)(qulonglong )>(_a, &OrgLxqtGlobalActionDaemonAdaptor::actionAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgLxqtGlobalActionDaemonAdaptor::*)(qulonglong , bool )>(_a, &OrgLxqtGlobalActionDaemonAdaptor::actionEnabled, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgLxqtGlobalActionDaemonAdaptor::*)(qulonglong )>(_a, &OrgLxqtGlobalActionDaemonAdaptor::actionModified, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgLxqtGlobalActionDaemonAdaptor::*)(qulonglong )>(_a, &OrgLxqtGlobalActionDaemonAdaptor::actionRemoved, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgLxqtGlobalActionDaemonAdaptor::*)(qulonglong )>(_a, &OrgLxqtGlobalActionDaemonAdaptor::actionShortcutChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgLxqtGlobalActionDaemonAdaptor::*)(qulonglong , qulonglong )>(_a, &OrgLxqtGlobalActionDaemonAdaptor::actionsSwapped, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgLxqtGlobalActionDaemonAdaptor::*)(qulonglong , const QString & )>(_a, &OrgLxqtGlobalActionDaemonAdaptor::clientActionSenderChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgLxqtGlobalActionDaemonAdaptor::*)(uint )>(_a, &OrgLxqtGlobalActionDaemonAdaptor::multipleActionsBehaviourChanged, 7))
            return;
    }
}

const QMetaObject *OrgLxqtGlobalActionDaemonAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgLxqtGlobalActionDaemonAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32OrgLxqtGlobalActionDaemonAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int OrgLxqtGlobalActionDaemonAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 30)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 30;
    }
    return _id;
}

// SIGNAL 0
void OrgLxqtGlobalActionDaemonAdaptor::actionAdded(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void OrgLxqtGlobalActionDaemonAdaptor::actionEnabled(qulonglong _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void OrgLxqtGlobalActionDaemonAdaptor::actionModified(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void OrgLxqtGlobalActionDaemonAdaptor::actionRemoved(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void OrgLxqtGlobalActionDaemonAdaptor::actionShortcutChanged(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void OrgLxqtGlobalActionDaemonAdaptor::actionsSwapped(qulonglong _t1, qulonglong _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void OrgLxqtGlobalActionDaemonAdaptor::clientActionSenderChanged(qulonglong _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void OrgLxqtGlobalActionDaemonAdaptor::multipleActionsBehaviourChanged(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
