/****************************************************************************
** Meta object code from reading C++ file 'org.lxqt.global_key_shortcuts.native.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "org.lxqt.global_key_shortcuts.native.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'org.lxqt.global_key_shortcuts.native.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.10.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN42OrgLxqtGlobal_key_shortcutsNativeInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgLxqtGlobal_key_shortcutsNativeInterface::qt_create_metaobjectdata<qt_meta_tag_ZN42OrgLxqtGlobal_key_shortcutsNativeInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgLxqtGlobal_key_shortcutsNativeInterface",
        "addClientAction",
        "QDBusPendingReply<QString,qulonglong>",
        "",
        "shortcut",
        "QDBusObjectPath",
        "path",
        "description",
        "QDBusReply<QString>",
        "qulonglong&",
        "id",
        "cancelShortcutGrab",
        "QDBusPendingReply<>",
        "changeClientActionShortcut",
        "QDBusPendingReply<QString>",
        "deactivateClientAction",
        "QDBusPendingReply<bool>",
        "enableClientAction",
        "enabled",
        "grabShortcut",
        "QDBusPendingReply<QString,bool,bool,bool>",
        "timeout",
        "bool&",
        "failed",
        "cancelled",
        "timedout",
        "isClientActionEnabled",
        "modifyClientAction",
        "removeClientAction"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'addClientAction'
        QtMocHelpers::SlotData<QDBusPendingReply<QString,qulonglong>(const QString &, const QDBusObjectPath &, const QString &)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 4 }, { 0x80000000 | 5, 6 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'addClientAction'
        QtMocHelpers::SlotData<QDBusReply<QString>(const QString &, const QDBusObjectPath &, const QString &, qulonglong &)>(1, 3, QMC::AccessPublic, 0x80000000 | 8, {{
            { QMetaType::QString, 4 }, { 0x80000000 | 5, 6 }, { QMetaType::QString, 7 }, { 0x80000000 | 9, 10 },
        }}),
        // Slot 'cancelShortcutGrab'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(11, 3, QMC::AccessPublic, 0x80000000 | 12),
        // Slot 'changeClientActionShortcut'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QDBusObjectPath &, const QString &)>(13, 3, QMC::AccessPublic, 0x80000000 | 14, {{
            { 0x80000000 | 5, 6 }, { QMetaType::QString, 4 },
        }}),
        // Slot 'deactivateClientAction'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QDBusObjectPath &)>(15, 3, QMC::AccessPublic, 0x80000000 | 16, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'enableClientAction'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QDBusObjectPath &, bool)>(17, 3, QMC::AccessPublic, 0x80000000 | 16, {{
            { 0x80000000 | 5, 6 }, { QMetaType::Bool, 18 },
        }}),
        // Slot 'grabShortcut'
        QtMocHelpers::SlotData<QDBusPendingReply<QString,bool,bool,bool>(uint)>(19, 3, QMC::AccessPublic, 0x80000000 | 20, {{
            { QMetaType::UInt, 21 },
        }}),
        // Slot 'grabShortcut'
        QtMocHelpers::SlotData<QDBusReply<QString>(uint, bool &, bool &, bool &)>(19, 3, QMC::AccessPublic, 0x80000000 | 8, {{
            { QMetaType::UInt, 21 }, { 0x80000000 | 22, 23 }, { 0x80000000 | 22, 24 }, { 0x80000000 | 22, 25 },
        }}),
        // Slot 'isClientActionEnabled'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QDBusObjectPath &)>(26, 3, QMC::AccessPublic, 0x80000000 | 16, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'modifyClientAction'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QDBusObjectPath &, const QString &)>(27, 3, QMC::AccessPublic, 0x80000000 | 16, {{
            { 0x80000000 | 5, 6 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'removeClientAction'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QDBusObjectPath &)>(28, 3, QMC::AccessPublic, 0x80000000 | 16, {{
            { 0x80000000 | 5, 6 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgLxqtGlobal_key_shortcutsNativeInterface, qt_meta_tag_ZN42OrgLxqtGlobal_key_shortcutsNativeInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgLxqtGlobal_key_shortcutsNativeInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN42OrgLxqtGlobal_key_shortcutsNativeInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN42OrgLxqtGlobal_key_shortcutsNativeInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN42OrgLxqtGlobal_key_shortcutsNativeInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgLxqtGlobal_key_shortcutsNativeInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgLxqtGlobal_key_shortcutsNativeInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QDBusPendingReply<QString,qulonglong> _r = _t->addClientAction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString,qulonglong>*>(_a[0]) = std::move(_r); }  break;
        case 1: { QDBusReply<QString> _r = _t->addClientAction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<qulonglong&>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<> _r = _t->cancelShortcutGrab();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<QString> _r = _t->changeClientActionShortcut((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<bool> _r = _t->deactivateClientAction((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<bool> _r = _t->enableClientAction((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<QString,bool,bool,bool> _r = _t->grabShortcut((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString,bool,bool,bool>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusReply<QString> _r = _t->grabShortcut((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<bool> _r = _t->isClientActionEnabled((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<bool> _r = _t->modifyClientAction((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<bool> _r = _t->removeClientAction((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *OrgLxqtGlobal_key_shortcutsNativeInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgLxqtGlobal_key_shortcutsNativeInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN42OrgLxqtGlobal_key_shortcutsNativeInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgLxqtGlobal_key_shortcutsNativeInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}
QT_WARNING_POP
