/****************************************************************************
** Meta object code from reading C++ file 'org.lxqt.global_key_shortcuts.native.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "org.lxqt.global_key_shortcuts.native.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'org.lxqt.global_key_shortcuts.native.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.10.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN32OrgLxqtGlobalActionNativeAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgLxqtGlobalActionNativeAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN32OrgLxqtGlobalActionNativeAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgLxqtGlobalActionNativeAdaptor",
        "D-Bus Interface",
        "org.lxqt.global_key_shortcuts.native",
        "D-Bus Introspection",
        "  <interface name=\"org.lxqt.global_key_shortcuts.native\">\n    <"
        "method name=\"addClientAction\">\n      <arg direction=\"in\" type"
        "=\"s\" name=\"shortcut\"/>\n      <arg direction=\"in\" type=\"o\""
        " name=\"path\"/>\n      <arg direction=\"in\" type=\"s\" name=\"de"
        "scription\"/>\n      <arg direction=\"out\" type=\"s\" name=\"used"
        "Shortcut\"/>\n      <arg direction=\"out\" type=\"t\" name=\"id\"/"
        ">\n    </method>\n    <method name=\"modifyClientAction\">\n      "
        "<arg direction=\"in\" type=\"o\" name=\"path\"/>\n      <arg direc"
        "tion=\"in\" type=\"s\" name=\"description\"/>\n      <arg directio"
        "n=\"out\" type=\"b\"/>\n    </method>\n    <method name=\"changeCl"
        "ientActionShortcut\">\n      <arg direction=\"in\" type=\"o\" name"
        "=\"path\"/>\n      <arg direction=\"in\" type=\"s\" name=\"shortcu"
        "t\"/>\n      <arg direction=\"out\" type=\"s\" name=\"usedShortcut"
        "\"/>\n    </method>\n    <method name=\"deactivateClientAction\">\n"
        "      <arg direction=\"in\" type=\"o\" name=\"path\"/>\n      <arg"
        " direction=\"out\" type=\"b\"/>\n    </method>\n    <method name=\""
        "removeClientAction\">\n      <arg direction=\"in\" type=\"o\" name"
        "=\"path\"/>\n      <arg direction=\"out\" type=\"b\"/>\n    </meth"
        "od>\n    <method name=\"enableClientAction\">\n      <arg directio"
        "n=\"in\" type=\"o\" name=\"path\"/>\n      <arg direction=\"in\" t"
        "ype=\"b\" name=\"enabled\"/>\n      <arg direction=\"out\" type=\""
        "b\"/>\n    </method>\n    <method name=\"isClientActionEnabled\">\n"
        "      <arg direction=\"in\" type=\"o\" name=\"path\"/>\n      <arg"
        " direction=\"out\" type=\"b\"/>\n    </method>\n    <method name=\""
        "grabShortcut\">\n      <arg direction=\"in\" type=\"u\" name=\"tim"
        "eout\"/>\n      <arg direction=\"out\" type=\"s\" name=\"shortcut\""
        "/>\n      <arg direction=\"out\" type=\"b\" name=\"failed\"/>\n   "
        "   <arg direction=\"out\" type=\"b\" name=\"cancelled\"/>\n      <"
        "arg direction=\"out\" type=\"b\" name=\"timedout\"/>\n    </method"
        ">\n    <method name=\"cancelShortcutGrab\"/>\n  </interface>\n",
        "addClientAction",
        "",
        "shortcut",
        "QDBusObjectPath",
        "path",
        "description",
        "qulonglong&",
        "id",
        "cancelShortcutGrab",
        "changeClientActionShortcut",
        "deactivateClientAction",
        "enableClientAction",
        "enabled",
        "grabShortcut",
        "timeout",
        "bool&",
        "failed",
        "cancelled",
        "timedout",
        "isClientActionEnabled",
        "modifyClientAction",
        "removeClientAction"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'addClientAction'
        QtMocHelpers::SlotData<QString(const QString &, const QDBusObjectPath &, const QString &, qulonglong &)>(5, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 7 }, { 0x80000000 | 8, 9 }, { QMetaType::QString, 10 }, { 0x80000000 | 11, 12 },
        }}),
        // Slot 'cancelShortcutGrab'
        QtMocHelpers::SlotData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'changeClientActionShortcut'
        QtMocHelpers::SlotData<QString(const QDBusObjectPath &, const QString &)>(14, 6, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 8, 9 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'deactivateClientAction'
        QtMocHelpers::SlotData<bool(const QDBusObjectPath &)>(15, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'enableClientAction'
        QtMocHelpers::SlotData<bool(const QDBusObjectPath &, bool)>(16, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 8, 9 }, { QMetaType::Bool, 17 },
        }}),
        // Slot 'grabShortcut'
        QtMocHelpers::SlotData<QString(uint, bool &, bool &, bool &)>(18, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::UInt, 19 }, { 0x80000000 | 20, 21 }, { 0x80000000 | 20, 22 }, { 0x80000000 | 20, 23 },
        }}),
        // Slot 'isClientActionEnabled'
        QtMocHelpers::SlotData<bool(const QDBusObjectPath &)>(24, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'modifyClientAction'
        QtMocHelpers::SlotData<bool(const QDBusObjectPath &, const QString &)>(25, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 8, 9 }, { QMetaType::QString, 10 },
        }}),
        // Slot 'removeClientAction'
        QtMocHelpers::SlotData<bool(const QDBusObjectPath &)>(26, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 8, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<OrgLxqtGlobalActionNativeAdaptor, qt_meta_tag_ZN32OrgLxqtGlobalActionNativeAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject OrgLxqtGlobalActionNativeAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32OrgLxqtGlobalActionNativeAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32OrgLxqtGlobalActionNativeAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN32OrgLxqtGlobalActionNativeAdaptorE_t>.metaTypes,
    nullptr
} };

void OrgLxqtGlobalActionNativeAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgLxqtGlobalActionNativeAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->addClientAction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<qulonglong&>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->cancelShortcutGrab(); break;
        case 2: { QString _r = _t->changeClientActionShortcut((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->deactivateClientAction((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->enableClientAction((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { QString _r = _t->grabShortcut((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->isClientActionEnabled((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->modifyClientAction((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->removeClientAction((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *OrgLxqtGlobalActionNativeAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgLxqtGlobalActionNativeAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32OrgLxqtGlobalActionNativeAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int OrgLxqtGlobalActionNativeAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}
QT_WARNING_POP
