/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.lxqt.global_key_shortcuts.client.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef ORG_LXQT_GLOBAL_KEY_SHORTCUTS_CLIENT_H
#define ORG_LXQT_GLOBAL_KEY_SHORTCUTS_CLIENT_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "action_p.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.lxqt.global_key_shortcuts.client
 */
class OrgLxqtActionClientAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.lxqt.global_key_shortcuts.client")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.lxqt.global_key_shortcuts.client\">\n"
"    <method name=\"activated\"/>\n"
"    <method name=\"shortcutChanged\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"oldShortcut\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"newShortcut\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    OrgLxqtActionClientAdaptor(GlobalKeyShortcut::ActionImpl *parent);
    ~OrgLxqtActionClientAdaptor() override;

    inline GlobalKeyShortcut::ActionImpl *parent() const
    { return static_cast<GlobalKeyShortcut::ActionImpl *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void activated();
    void shortcutChanged(const QString &oldShortcut, const QString &newShortcut);
Q_SIGNALS: // SIGNALS
};

#endif
