/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.lxqt.global_key_shortcuts.daemon.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef ORG_LXQT_GLOBAL_KEY_SHORTCUTS_DAEMON_H
#define ORG_LXQT_GLOBAL_KEY_SHORTCUTS_DAEMON_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "daemon_adaptor.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.lxqt.global_key_shortcuts.daemon
 */
class OrgLxqtGlobalActionDaemonAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.lxqt.global_key_shortcuts.daemon")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.lxqt.global_key_shortcuts.daemon\">\n"
"    <method name=\"addMethodAction\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"shortcut\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"service\"/>\n"
"      <arg direction=\"in\" type=\"o\" name=\"path\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"interface\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"method\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"description\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"usedShortcut\"/>\n"
"      <arg direction=\"out\" type=\"t\" name=\"id\"/>\n"
"    </method>\n"
"    <method name=\"addCommandAction\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"shortcut\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"command\"/>\n"
"      <arg direction=\"in\" type=\"as\" name=\"arguments\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"description\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"usedShortcut\"/>\n"
"      <arg direction=\"out\" type=\"t\" name=\"id\"/>\n"
"    </method>\n"
"    <signal name=\"actionAdded\">\n"
"      <arg type=\"t\" name=\"id\"/>\n"
"    </signal>\n"
"    <method name=\"modifyActionDescription\">\n"
"      <arg direction=\"in\" type=\"t\" name=\"id\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"description\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"modifyMethodAction\">\n"
"      <arg direction=\"in\" type=\"t\" name=\"id\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"service\"/>\n"
"      <arg direction=\"in\" type=\"o\" name=\"path\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"interface\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"method\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"description\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"modifyCommandAction\">\n"
"      <arg direction=\"in\" type=\"t\" name=\"id\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"command\"/>\n"
"      <arg direction=\"in\" type=\"as\" name=\"arguments\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"description\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <signal name=\"actionModified\">\n"
"      <arg type=\"t\" name=\"id\"/>\n"
"    </signal>\n"
"    <method name=\"enableAction\">\n"
"      <arg direction=\"in\" type=\"t\" name=\"id\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"enabled\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"isActionEnabled\">\n"
"      <arg direction=\"in\" type=\"t\" name=\"id\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <signal name=\"actionEnabled\">\n"
"      <arg type=\"t\" name=\"id\"/>\n"
"      <arg type=\"b\" name=\"enabled\"/>\n"
"    </signal>\n"
"    <method name=\"getClientActionSender\">\n"
"      <arg direction=\"in\" type=\"t\" name=\"id\"/>\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <signal name=\"clientActionSenderChanged\">\n"
"      <arg type=\"t\" name=\"id\"/>\n"
"      <arg type=\"s\" name=\"sender\"/>\n"
"    </signal>\n"
"    <method name=\"changeShortcut\">\n"
"      <arg direction=\"in\" type=\"t\" name=\"id\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"shortcut\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"usedShortcut\"/>\n"
"    </method>\n"
"    <signal name=\"actionShortcutChanged\">\n"
"      <arg type=\"t\" name=\"id\"/>\n"
"    </signal>\n"
"    <method name=\"swapActions\">\n"
"      <arg direction=\"in\" type=\"t\" name=\"id1\"/>\n"
"      <arg direction=\"in\" type=\"t\" name=\"id2\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <signal name=\"actionsSwapped\">\n"
"      <arg type=\"t\" name=\"id1\"/>\n"
"      <arg type=\"t\" name=\"id2\"/>\n"
"    </signal>\n"
"    <method name=\"removeAction\">\n"
"      <arg direction=\"in\" type=\"t\" name=\"id\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <signal name=\"actionRemoved\">\n"
"      <arg type=\"t\" name=\"id\"/>\n"
"    </signal>\n"
"    <method name=\"setMultipleActionsBehaviour\">\n"
"      <arg direction=\"in\" type=\"u\" name=\"behaviour\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"getMultipleActionsBehaviour\">\n"
"      <arg direction=\"out\" type=\"u\"/>\n"
"    </method>\n"
"    <signal name=\"multipleActionsBehaviourChanged\">\n"
"      <arg type=\"u\" name=\"behaviour\"/>\n"
"    </signal>\n"
"    <method name=\"getAllActionIds\">\n"
"      <annotation value=\"QList&lt;qulonglong&gt;\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"      <arg direction=\"out\" type=\"at\"/>\n"
"    </method>\n"
"    <method name=\"getActionById\">\n"
"      <arg direction=\"in\" type=\"t\" name=\"id\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"shortcut\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"description\"/>\n"
"      <arg direction=\"out\" type=\"b\" name=\"enabled\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"type\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"info\"/>\n"
"    </method>\n"
"    <method name=\"getAllActions\">\n"
"      <annotation value=\"QMap_qulonglong_GeneralActionInfo\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"      <arg direction=\"out\" type=\"a{t(ssbss)}\" name=\"info\"/>\n"
"    </method>\n"
"    <method name=\"getClientActionInfoById\">\n"
"      <arg direction=\"in\" type=\"t\" name=\"id\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"shortcut\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"description\"/>\n"
"      <arg direction=\"out\" type=\"b\" name=\"enabled\"/>\n"
"      <arg direction=\"out\" type=\"o\" name=\"path\"/>\n"
"    </method>\n"
"    <method name=\"getMethodActionInfoById\">\n"
"      <arg direction=\"in\" type=\"t\" name=\"id\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"shortcut\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"description\"/>\n"
"      <arg direction=\"out\" type=\"b\" name=\"enabled\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"service\"/>\n"
"      <arg direction=\"out\" type=\"o\" name=\"path\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"interface\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"method\"/>\n"
"    </method>\n"
"    <method name=\"getCommandActionInfoById\">\n"
"      <arg direction=\"in\" type=\"t\" name=\"id\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"shortcut\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"description\"/>\n"
"      <arg direction=\"out\" type=\"b\" name=\"enabled\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"command\"/>\n"
"      <arg direction=\"out\" type=\"as\" name=\"arguments\"/>\n"
"    </method>\n"
"    <method name=\"grabShortcut\">\n"
"      <arg direction=\"in\" type=\"u\" name=\"timeout\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"shortcut\"/>\n"
"      <arg direction=\"out\" type=\"b\" name=\"failed\"/>\n"
"      <arg direction=\"out\" type=\"b\" name=\"cancelled\"/>\n"
"      <arg direction=\"out\" type=\"b\" name=\"timedout\"/>\n"
"    </method>\n"
"    <method name=\"cancelShortcutGrab\"/>\n"
"    <method name=\"quit\">\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    OrgLxqtGlobalActionDaemonAdaptor(DaemonAdaptor *parent);
    ~OrgLxqtGlobalActionDaemonAdaptor() override;

    inline DaemonAdaptor *parent() const
    { return static_cast<DaemonAdaptor *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    QString addCommandAction(const QString &shortcut, const QString &command, const QStringList &arguments, const QString &description, qulonglong &id);
    QString addMethodAction(const QString &shortcut, const QString &service, const QDBusObjectPath &path, const QString &interface, const QString &method, const QString &description, qulonglong &id);
    void cancelShortcutGrab();
    QString changeShortcut(qulonglong id, const QString &shortcut);
    bool enableAction(qulonglong id, bool enabled);
    bool getActionById(qulonglong id, QString &shortcut, QString &description, bool &enabled, QString &type, QString &info);
    QList<qulonglong> getAllActionIds();
    QMap_qulonglong_GeneralActionInfo getAllActions();
    bool getClientActionInfoById(qulonglong id, QString &shortcut, QString &description, bool &enabled, QDBusObjectPath &path);
    QString getClientActionSender(qulonglong id);
    bool getCommandActionInfoById(qulonglong id, QString &shortcut, QString &description, bool &enabled, QString &command, QStringList &arguments);
    bool getMethodActionInfoById(qulonglong id, QString &shortcut, QString &description, bool &enabled, QString &service, QDBusObjectPath &path, QString &interface, QString &method);
    uint getMultipleActionsBehaviour();
    QString grabShortcut(uint timeout, bool &failed, bool &cancelled, bool &timedout);
    bool isActionEnabled(qulonglong id);
    bool modifyActionDescription(qulonglong id, const QString &description);
    bool modifyCommandAction(qulonglong id, const QString &command, const QStringList &arguments, const QString &description);
    bool modifyMethodAction(qulonglong id, const QString &service, const QDBusObjectPath &path, const QString &interface, const QString &method, const QString &description);
    Q_NOREPLY void quit();
    bool removeAction(qulonglong id);
    bool setMultipleActionsBehaviour(uint behaviour);
    bool swapActions(qulonglong id1, qulonglong id2);
Q_SIGNALS: // SIGNALS
    void actionAdded(qulonglong id);
    void actionEnabled(qulonglong id, bool enabled);
    void actionModified(qulonglong id);
    void actionRemoved(qulonglong id);
    void actionShortcutChanged(qulonglong id);
    void actionsSwapped(qulonglong id1, qulonglong id2);
    void clientActionSenderChanged(qulonglong id, const QString &sender);
    void multipleActionsBehaviourChanged(uint behaviour);
};

#endif
