/****************************************************************************
** Meta object code from reading C++ file 'daemon_adaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../lxqt-globalkeys-2.3.0/daemon/daemon_adaptor.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'daemon_adaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.10.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13DaemonAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto DaemonAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN13DaemonAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DaemonAdaptor",
        "actionAdded",
        "",
        "id",
        "actionModified",
        "actionRemoved",
        "actionShortcutChanged",
        "actionEnabled",
        "enabled",
        "clientActionSenderChanged",
        "sender",
        "actionsSwapped",
        "id1",
        "id2",
        "multipleActionsBehaviourChanged",
        "behaviour",
        "onAddMethodAction",
        "std::pair<QString,qulonglong>&",
        "QDBusObjectPath",
        "onAddCommandAction",
        "onModifyActionDescription",
        "bool&",
        "onModifyMethodAction",
        "onModifyCommandAction",
        "onEnableAction",
        "onIsActionEnabled",
        "onGetClientActionSender",
        "QString&",
        "onChangeShortcut",
        "onSwapActions",
        "onRemoveAction",
        "onSetMultipleActionsBehaviour",
        "MultipleActionsBehaviour",
        "onGetMultipleActionsBehaviour",
        "MultipleActionsBehaviour&",
        "onGetAllActionIds",
        "QList<qulonglong>&",
        "onGetActionById",
        "std::pair<bool,GeneralActionInfo>&",
        "onGetAllActions",
        "QMap<qulonglong,GeneralActionInfo>&",
        "onGetClientActionInfoById",
        "std::pair<bool,ClientActionInfo>&",
        "onGetMethodActionInfoById",
        "std::pair<bool,MethodActionInfo>&",
        "onGetCommandActionInfoById",
        "std::pair<bool,CommandActionInfo>&",
        "onGrabShortcut",
        "QDBusMessage",
        "onCancelShortcutGrab",
        "onQuit",
        "addMethodAction",
        "shortcut",
        "service",
        "path",
        "interface",
        "method",
        "description",
        "qulonglong&",
        "addCommandAction",
        "command",
        "arguments",
        "modifyActionDescription",
        "modifyMethodAction",
        "modifyCommandAction",
        "enableAction",
        "isActionEnabled",
        "getClientActionSender",
        "changeShortcut",
        "swapActions",
        "removeAction",
        "setMultipleActionsBehaviour",
        "getMultipleActionsBehaviour",
        "getAllActionIds",
        "QList<qulonglong>",
        "getAllActions",
        "QMap<qulonglong,GeneralActionInfo>",
        "getActionById",
        "type",
        "info",
        "getClientActionInfoById",
        "QDBusObjectPath&",
        "getMethodActionInfoById",
        "getCommandActionInfoById",
        "QStringList&",
        "grabShortcut",
        "timeout",
        "failed",
        "cancelled",
        "timedout",
        "cancelShortcutGrab",
        "quit",
        "emit_actionAdded",
        "emit_actionModified",
        "emit_actionRemoved",
        "emit_actionShortcutChanged",
        "emit_actionEnabled",
        "emit_clientActionSenderChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'actionAdded'
        QtMocHelpers::SignalData<void(qulonglong)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 },
        }}),
        // Signal 'actionModified'
        QtMocHelpers::SignalData<void(qulonglong)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 },
        }}),
        // Signal 'actionRemoved'
        QtMocHelpers::SignalData<void(qulonglong)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 },
        }}),
        // Signal 'actionShortcutChanged'
        QtMocHelpers::SignalData<void(qulonglong)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 },
        }}),
        // Signal 'actionEnabled'
        QtMocHelpers::SignalData<void(qulonglong, bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { QMetaType::Bool, 8 },
        }}),
        // Signal 'clientActionSenderChanged'
        QtMocHelpers::SignalData<void(qulonglong, const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { QMetaType::QString, 10 },
        }}),
        // Signal 'actionsSwapped'
        QtMocHelpers::SignalData<void(qulonglong, qulonglong)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 12 }, { QMetaType::ULongLong, 13 },
        }}),
        // Signal 'multipleActionsBehaviourChanged'
        QtMocHelpers::SignalData<void(uint)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 15 },
        }}),
        // Signal 'onAddMethodAction'
        QtMocHelpers::SignalData<void(QPair<QString,qulonglong> &, const QString &, const QString &, const QDBusObjectPath &, const QString &, const QString &, const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 2 }, { QMetaType::QString, 2 }, { QMetaType::QString, 2 }, { 0x80000000 | 18, 2 },
            { QMetaType::QString, 2 }, { QMetaType::QString, 2 }, { QMetaType::QString, 2 },
        }}),
        // Signal 'onAddCommandAction'
        QtMocHelpers::SignalData<void(QPair<QString,qulonglong> &, const QString &, const QString &, const QStringList &, const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 2 }, { QMetaType::QString, 2 }, { QMetaType::QString, 2 }, { QMetaType::QStringList, 2 },
            { QMetaType::QString, 2 },
        }}),
        // Signal 'onModifyActionDescription'
        QtMocHelpers::SignalData<void(bool &, qulonglong, const QString &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 2 }, { QMetaType::ULongLong, 2 }, { QMetaType::QString, 2 },
        }}),
        // Signal 'onModifyMethodAction'
        QtMocHelpers::SignalData<void(bool &, qulonglong, const QString &, const QDBusObjectPath &, const QString &, const QString &, const QString &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 2 }, { QMetaType::ULongLong, 2 }, { QMetaType::QString, 2 }, { 0x80000000 | 18, 2 },
            { QMetaType::QString, 2 }, { QMetaType::QString, 2 }, { QMetaType::QString, 2 },
        }}),
        // Signal 'onModifyCommandAction'
        QtMocHelpers::SignalData<void(bool &, qulonglong, const QString &, const QStringList &, const QString &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 2 }, { QMetaType::ULongLong, 2 }, { QMetaType::QString, 2 }, { QMetaType::QStringList, 2 },
            { QMetaType::QString, 2 },
        }}),
        // Signal 'onEnableAction'
        QtMocHelpers::SignalData<void(bool &, qulonglong, bool)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 2 }, { QMetaType::ULongLong, 2 }, { QMetaType::Bool, 2 },
        }}),
        // Signal 'onIsActionEnabled'
        QtMocHelpers::SignalData<void(bool &, qulonglong)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 2 }, { QMetaType::ULongLong, 2 },
        }}),
        // Signal 'onGetClientActionSender'
        QtMocHelpers::SignalData<void(QString &, qulonglong)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 2 }, { QMetaType::ULongLong, 2 },
        }}),
        // Signal 'onChangeShortcut'
        QtMocHelpers::SignalData<void(QString &, qulonglong, const QString &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 2 }, { QMetaType::ULongLong, 2 }, { QMetaType::QString, 2 },
        }}),
        // Signal 'onSwapActions'
        QtMocHelpers::SignalData<void(bool &, qulonglong, qulonglong)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 2 }, { QMetaType::ULongLong, 2 }, { QMetaType::ULongLong, 2 },
        }}),
        // Signal 'onRemoveAction'
        QtMocHelpers::SignalData<void(bool &, qulonglong)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 2 }, { QMetaType::ULongLong, 2 },
        }}),
        // Signal 'onSetMultipleActionsBehaviour'
        QtMocHelpers::SignalData<void(const MultipleActionsBehaviour &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 2 },
        }}),
        // Signal 'onGetMultipleActionsBehaviour'
        QtMocHelpers::SignalData<void(MultipleActionsBehaviour &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 34, 2 },
        }}),
        // Signal 'onGetAllActionIds'
        QtMocHelpers::SignalData<void(QList<qulonglong> &)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 2 },
        }}),
        // Signal 'onGetActionById'
        QtMocHelpers::SignalData<void(QPair<bool,GeneralActionInfo> &, qulonglong)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 38, 2 }, { QMetaType::ULongLong, 2 },
        }}),
        // Signal 'onGetAllActions'
        QtMocHelpers::SignalData<void(QMap<qulonglong,GeneralActionInfo> &)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 40, 2 },
        }}),
        // Signal 'onGetClientActionInfoById'
        QtMocHelpers::SignalData<void(QPair<bool,ClientActionInfo> &, qulonglong)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 42, 2 }, { QMetaType::ULongLong, 2 },
        }}),
        // Signal 'onGetMethodActionInfoById'
        QtMocHelpers::SignalData<void(QPair<bool,MethodActionInfo> &, qulonglong)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 44, 2 }, { QMetaType::ULongLong, 2 },
        }}),
        // Signal 'onGetCommandActionInfoById'
        QtMocHelpers::SignalData<void(QPair<bool,CommandActionInfo> &, qulonglong)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 46, 2 }, { QMetaType::ULongLong, 2 },
        }}),
        // Signal 'onGrabShortcut'
        QtMocHelpers::SignalData<void(uint, QString &, bool &, bool &, bool &, const QDBusMessage &)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 2 }, { 0x80000000 | 27, 2 }, { 0x80000000 | 21, 2 }, { 0x80000000 | 21, 2 },
            { 0x80000000 | 21, 2 }, { 0x80000000 | 48, 2 },
        }}),
        // Signal 'onCancelShortcutGrab'
        QtMocHelpers::SignalData<void()>(49, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'onQuit'
        QtMocHelpers::SignalData<void()>(50, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addMethodAction'
        QtMocHelpers::SlotData<QString(const QString &, const QString &, const QDBusObjectPath &, const QString &, const QString &, const QString &, qulonglong &)>(51, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 52 }, { QMetaType::QString, 53 }, { 0x80000000 | 18, 54 }, { QMetaType::QString, 55 },
            { QMetaType::QString, 56 }, { QMetaType::QString, 57 }, { 0x80000000 | 58, 3 },
        }}),
        // Slot 'addCommandAction'
        QtMocHelpers::SlotData<QString(const QString &, const QString &, const QStringList &, const QString &, qulonglong &)>(59, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 52 }, { QMetaType::QString, 60 }, { QMetaType::QStringList, 61 }, { QMetaType::QString, 57 },
            { 0x80000000 | 58, 3 },
        }}),
        // Slot 'modifyActionDescription'
        QtMocHelpers::SlotData<bool(qulonglong, const QString &)>(62, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 3 }, { QMetaType::QString, 57 },
        }}),
        // Slot 'modifyMethodAction'
        QtMocHelpers::SlotData<bool(qulonglong, const QString &, const QDBusObjectPath &, const QString &, const QString &, const QString &)>(63, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 3 }, { QMetaType::QString, 53 }, { 0x80000000 | 18, 54 }, { QMetaType::QString, 55 },
            { QMetaType::QString, 56 }, { QMetaType::QString, 57 },
        }}),
        // Slot 'modifyCommandAction'
        QtMocHelpers::SlotData<bool(qulonglong, const QString &, const QStringList &, const QString &)>(64, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 3 }, { QMetaType::QString, 60 }, { QMetaType::QStringList, 61 }, { QMetaType::QString, 57 },
        }}),
        // Slot 'enableAction'
        QtMocHelpers::SlotData<bool(qulonglong, bool)>(65, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 3 }, { QMetaType::Bool, 8 },
        }}),
        // Slot 'isActionEnabled'
        QtMocHelpers::SlotData<bool(qulonglong)>(66, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 3 },
        }}),
        // Slot 'getClientActionSender'
        QtMocHelpers::SlotData<QString(qulonglong)>(67, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::ULongLong, 3 },
        }}),
        // Slot 'changeShortcut'
        QtMocHelpers::SlotData<QString(qulonglong, const QString &)>(68, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::ULongLong, 3 }, { QMetaType::QString, 52 },
        }}),
        // Slot 'swapActions'
        QtMocHelpers::SlotData<bool(qulonglong, qulonglong)>(69, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 12 }, { QMetaType::ULongLong, 13 },
        }}),
        // Slot 'removeAction'
        QtMocHelpers::SlotData<bool(qulonglong)>(70, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 3 },
        }}),
        // Slot 'setMultipleActionsBehaviour'
        QtMocHelpers::SlotData<bool(uint)>(71, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::UInt, 15 },
        }}),
        // Slot 'getMultipleActionsBehaviour'
        QtMocHelpers::SlotData<uint()>(72, 2, QMC::AccessPublic, QMetaType::UInt),
        // Slot 'getAllActionIds'
        QtMocHelpers::SlotData<QList<qulonglong>()>(73, 2, QMC::AccessPublic, 0x80000000 | 74),
        // Slot 'getAllActions'
        QtMocHelpers::SlotData<QMap<qulonglong,GeneralActionInfo>()>(75, 2, QMC::AccessPublic, 0x80000000 | 76),
        // Slot 'getActionById'
        QtMocHelpers::SlotData<bool(qulonglong, QString &, QString &, bool &, QString &, QString &)>(77, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 27, 52 }, { 0x80000000 | 27, 57 }, { 0x80000000 | 21, 8 },
            { 0x80000000 | 27, 78 }, { 0x80000000 | 27, 79 },
        }}),
        // Slot 'getClientActionInfoById'
        QtMocHelpers::SlotData<bool(qulonglong, QString &, QString &, bool &, QDBusObjectPath &)>(80, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 27, 52 }, { 0x80000000 | 27, 57 }, { 0x80000000 | 21, 8 },
            { 0x80000000 | 81, 54 },
        }}),
        // Slot 'getMethodActionInfoById'
        QtMocHelpers::SlotData<bool(qulonglong, QString &, QString &, bool &, QString &, QDBusObjectPath &, QString &, QString &)>(82, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 27, 52 }, { 0x80000000 | 27, 57 }, { 0x80000000 | 21, 8 },
            { 0x80000000 | 27, 53 }, { 0x80000000 | 81, 54 }, { 0x80000000 | 27, 55 }, { 0x80000000 | 27, 56 },
        }}),
        // Slot 'getCommandActionInfoById'
        QtMocHelpers::SlotData<bool(qulonglong, QString &, QString &, bool &, QString &, QStringList &)>(83, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 27, 52 }, { 0x80000000 | 27, 57 }, { 0x80000000 | 21, 8 },
            { 0x80000000 | 27, 60 }, { 0x80000000 | 84, 61 },
        }}),
        // Slot 'grabShortcut'
        QtMocHelpers::SlotData<QString(uint, bool &, bool &, bool &)>(85, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::UInt, 86 }, { 0x80000000 | 21, 87 }, { 0x80000000 | 21, 88 }, { 0x80000000 | 21, 89 },
        }}),
        // Slot 'cancelShortcutGrab'
        QtMocHelpers::SlotData<void()>(90, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'quit'
        QtMocHelpers::SlotData<void()>(91, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'emit_actionAdded'
        QtMocHelpers::SlotData<void(qulonglong)>(92, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 },
        }}),
        // Slot 'emit_actionModified'
        QtMocHelpers::SlotData<void(qulonglong)>(93, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 },
        }}),
        // Slot 'emit_actionRemoved'
        QtMocHelpers::SlotData<void(qulonglong)>(94, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 },
        }}),
        // Slot 'emit_actionShortcutChanged'
        QtMocHelpers::SlotData<void(qulonglong)>(95, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 },
        }}),
        // Slot 'emit_actionEnabled'
        QtMocHelpers::SlotData<void(qulonglong, bool)>(96, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { QMetaType::Bool, 8 },
        }}),
        // Slot 'emit_clientActionSenderChanged'
        QtMocHelpers::SlotData<void(qulonglong, const QString &)>(97, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { QMetaType::QString, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DaemonAdaptor, qt_meta_tag_ZN13DaemonAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DaemonAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DaemonAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DaemonAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13DaemonAdaptorE_t>.metaTypes,
    nullptr
} };

void DaemonAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DaemonAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->actionAdded((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 1: _t->actionModified((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 2: _t->actionRemoved((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 3: _t->actionShortcutChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 4: _t->actionEnabled((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 5: _t->clientActionSenderChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->actionsSwapped((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2]))); break;
        case 7: _t->multipleActionsBehaviourChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 8: _t->onAddMethodAction((*reinterpret_cast<std::add_pointer_t<std::pair<QString,qulonglong>&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[7]))); break;
        case 9: _t->onAddCommandAction((*reinterpret_cast<std::add_pointer_t<std::pair<QString,qulonglong>&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5]))); break;
        case 10: _t->onModifyActionDescription((*reinterpret_cast<std::add_pointer_t<bool&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 11: _t->onModifyMethodAction((*reinterpret_cast<std::add_pointer_t<bool&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[7]))); break;
        case 12: _t->onModifyCommandAction((*reinterpret_cast<std::add_pointer_t<bool&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5]))); break;
        case 13: _t->onEnableAction((*reinterpret_cast<std::add_pointer_t<bool&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 14: _t->onIsActionEnabled((*reinterpret_cast<std::add_pointer_t<bool&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2]))); break;
        case 15: _t->onGetClientActionSender((*reinterpret_cast<std::add_pointer_t<QString&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2]))); break;
        case 16: _t->onChangeShortcut((*reinterpret_cast<std::add_pointer_t<QString&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 17: _t->onSwapActions((*reinterpret_cast<std::add_pointer_t<bool&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[3]))); break;
        case 18: _t->onRemoveAction((*reinterpret_cast<std::add_pointer_t<bool&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2]))); break;
        case 19: _t->onSetMultipleActionsBehaviour((*reinterpret_cast<std::add_pointer_t<MultipleActionsBehaviour>>(_a[1]))); break;
        case 20: _t->onGetMultipleActionsBehaviour((*reinterpret_cast<std::add_pointer_t<MultipleActionsBehaviour&>>(_a[1]))); break;
        case 21: _t->onGetAllActionIds((*reinterpret_cast<std::add_pointer_t<QList<qulonglong>&>>(_a[1]))); break;
        case 22: _t->onGetActionById((*reinterpret_cast<std::add_pointer_t<std::pair<bool,GeneralActionInfo>&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2]))); break;
        case 23: _t->onGetAllActions((*reinterpret_cast<std::add_pointer_t<QMap<qulonglong,GeneralActionInfo>&>>(_a[1]))); break;
        case 24: _t->onGetClientActionInfoById((*reinterpret_cast<std::add_pointer_t<std::pair<bool,ClientActionInfo>&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2]))); break;
        case 25: _t->onGetMethodActionInfoById((*reinterpret_cast<std::add_pointer_t<std::pair<bool,MethodActionInfo>&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2]))); break;
        case 26: _t->onGetCommandActionInfoById((*reinterpret_cast<std::add_pointer_t<std::pair<bool,CommandActionInfo>&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2]))); break;
        case 27: _t->onGrabShortcut((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[6]))); break;
        case 28: _t->onCancelShortcutGrab(); break;
        case 29: _t->onQuit(); break;
        case 30: { QString _r = _t->addMethodAction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<qulonglong&>>(_a[7])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 31: { QString _r = _t->addCommandAction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<qulonglong&>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 32: { bool _r = _t->modifyActionDescription((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 33: { bool _r = _t->modifyMethodAction((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 34: { bool _r = _t->modifyCommandAction((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 35: { bool _r = _t->enableAction((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 36: { bool _r = _t->isActionEnabled((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 37: { QString _r = _t->getClientActionSender((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 38: { QString _r = _t->changeShortcut((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 39: { bool _r = _t->swapActions((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 40: { bool _r = _t->removeAction((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 41: { bool _r = _t->setMultipleActionsBehaviour((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 42: { uint _r = _t->getMultipleActionsBehaviour();
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 43: { QList<qulonglong> _r = _t->getAllActionIds();
            if (_a[0]) *reinterpret_cast<QList<qulonglong>*>(_a[0]) = std::move(_r); }  break;
        case 44: { QMap<qulonglong,GeneralActionInfo> _r = _t->getAllActions();
            if (_a[0]) *reinterpret_cast<QMap<qulonglong,GeneralActionInfo>*>(_a[0]) = std::move(_r); }  break;
        case 45: { bool _r = _t->getActionById((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[6])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 46: { bool _r = _t->getClientActionInfoById((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath&>>(_a[5])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 47: { bool _r = _t->getMethodActionInfoById((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath&>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[8])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 48: { bool _r = _t->getCommandActionInfoById((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QStringList&>>(_a[6])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 49: { QString _r = _t->grabShortcut((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 50: _t->cancelShortcutGrab(); break;
        case 51: _t->quit(); break;
        case 52: _t->emit_actionAdded((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 53: _t->emit_actionModified((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 54: _t->emit_actionRemoved((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 55: _t->emit_actionShortcutChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 56: _t->emit_actionEnabled((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 57: _t->emit_clientActionSenderChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DaemonAdaptor::*)(qulonglong )>(_a, &DaemonAdaptor::actionAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DaemonAdaptor::*)(qulonglong )>(_a, &DaemonAdaptor::actionModified, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DaemonAdaptor::*)(qulonglong )>(_a, &DaemonAdaptor::actionRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DaemonAdaptor::*)(qulonglong )>(_a, &DaemonAdaptor::actionShortcutChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DaemonAdaptor::*)(qulonglong , bool )>(_a, &DaemonAdaptor::actionEnabled, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DaemonAdaptor::*)(qulonglong , const QString & )>(_a, &DaemonAdaptor::clientActionSenderChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DaemonAdaptor::*)(qulonglong , qulonglong )>(_a, &DaemonAdaptor::actionsSwapped, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DaemonAdaptor::*)(uint )>(_a, &DaemonAdaptor::multipleActionsBehaviourChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DaemonAdaptor::*)(QPair<QString,qulonglong> & , const QString & , const QString & , const QDBusObjectPath & , const QString & , const QString & , const QString & )>(_a, &DaemonAdaptor::onAddMethodAction, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DaemonAdaptor::*)(QPair<QString,qulonglong> & , const QString & , const QString & , const QStringList & , const QString & )>(_a, &DaemonAdaptor::onAddCommandAction, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DaemonAdaptor::*)(bool & , qulonglong , const QString & )>(_a, &DaemonAdaptor::onModifyActionDescription, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DaemonAdaptor::*)(bool & , qulonglong , const QString & , const QDBusObjectPath & , const QString & , const QString & , const QString & )>(_a, &DaemonAdaptor::onModifyMethodAction, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DaemonAdaptor::*)(bool & , qulonglong , const QString & , const QStringList & , const QString & )>(_a, &DaemonAdaptor::onModifyCommandAction, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DaemonAdaptor::*)(bool & , qulonglong , bool )>(_a, &DaemonAdaptor::onEnableAction, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DaemonAdaptor::*)(bool & , qulonglong )>(_a, &DaemonAdaptor::onIsActionEnabled, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DaemonAdaptor::*)(QString & , qulonglong )>(_a, &DaemonAdaptor::onGetClientActionSender, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (DaemonAdaptor::*)(QString & , qulonglong , const QString & )>(_a, &DaemonAdaptor::onChangeShortcut, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (DaemonAdaptor::*)(bool & , qulonglong , qulonglong )>(_a, &DaemonAdaptor::onSwapActions, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (DaemonAdaptor::*)(bool & , qulonglong )>(_a, &DaemonAdaptor::onRemoveAction, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (DaemonAdaptor::*)(const MultipleActionsBehaviour & )>(_a, &DaemonAdaptor::onSetMultipleActionsBehaviour, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (DaemonAdaptor::*)(MultipleActionsBehaviour & )>(_a, &DaemonAdaptor::onGetMultipleActionsBehaviour, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (DaemonAdaptor::*)(QList<qulonglong> & )>(_a, &DaemonAdaptor::onGetAllActionIds, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (DaemonAdaptor::*)(QPair<bool,GeneralActionInfo> & , qulonglong )>(_a, &DaemonAdaptor::onGetActionById, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (DaemonAdaptor::*)(QMap<qulonglong,GeneralActionInfo> & )>(_a, &DaemonAdaptor::onGetAllActions, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (DaemonAdaptor::*)(QPair<bool,ClientActionInfo> & , qulonglong )>(_a, &DaemonAdaptor::onGetClientActionInfoById, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (DaemonAdaptor::*)(QPair<bool,MethodActionInfo> & , qulonglong )>(_a, &DaemonAdaptor::onGetMethodActionInfoById, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (DaemonAdaptor::*)(QPair<bool,CommandActionInfo> & , qulonglong )>(_a, &DaemonAdaptor::onGetCommandActionInfoById, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (DaemonAdaptor::*)(uint , QString & , bool & , bool & , bool & , const QDBusMessage & )>(_a, &DaemonAdaptor::onGrabShortcut, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (DaemonAdaptor::*)()>(_a, &DaemonAdaptor::onCancelShortcutGrab, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (DaemonAdaptor::*)()>(_a, &DaemonAdaptor::onQuit, 29))
            return;
    }
}

const QMetaObject *DaemonAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DaemonAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DaemonAdaptorE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return QObject::qt_metacast(_clname);
}

int DaemonAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 58)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 58;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 58)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 58;
    }
    return _id;
}

// SIGNAL 0
void DaemonAdaptor::actionAdded(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DaemonAdaptor::actionModified(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DaemonAdaptor::actionRemoved(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DaemonAdaptor::actionShortcutChanged(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void DaemonAdaptor::actionEnabled(qulonglong _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void DaemonAdaptor::clientActionSenderChanged(qulonglong _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void DaemonAdaptor::actionsSwapped(qulonglong _t1, qulonglong _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void DaemonAdaptor::multipleActionsBehaviourChanged(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void DaemonAdaptor::onAddMethodAction(QPair<QString,qulonglong> & _t1, const QString & _t2, const QString & _t3, const QDBusObjectPath & _t4, const QString & _t5, const QString & _t6, const QString & _t7)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2, _t3, _t4, _t5, _t6, _t7);
}

// SIGNAL 9
void DaemonAdaptor::onAddCommandAction(QPair<QString,qulonglong> & _t1, const QString & _t2, const QString & _t3, const QStringList & _t4, const QString & _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 10
void DaemonAdaptor::onModifyActionDescription(bool & _t1, qulonglong _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2, _t3);
}

// SIGNAL 11
void DaemonAdaptor::onModifyMethodAction(bool & _t1, qulonglong _t2, const QString & _t3, const QDBusObjectPath & _t4, const QString & _t5, const QString & _t6, const QString & _t7)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1, _t2, _t3, _t4, _t5, _t6, _t7);
}

// SIGNAL 12
void DaemonAdaptor::onModifyCommandAction(bool & _t1, qulonglong _t2, const QString & _t3, const QStringList & _t4, const QString & _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 13
void DaemonAdaptor::onEnableAction(bool & _t1, qulonglong _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2, _t3);
}

// SIGNAL 14
void DaemonAdaptor::onIsActionEnabled(bool & _t1, qulonglong _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2);
}

// SIGNAL 15
void DaemonAdaptor::onGetClientActionSender(QString & _t1, qulonglong _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1, _t2);
}

// SIGNAL 16
void DaemonAdaptor::onChangeShortcut(QString & _t1, qulonglong _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1, _t2, _t3);
}

// SIGNAL 17
void DaemonAdaptor::onSwapActions(bool & _t1, qulonglong _t2, qulonglong _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1, _t2, _t3);
}

// SIGNAL 18
void DaemonAdaptor::onRemoveAction(bool & _t1, qulonglong _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1, _t2);
}

// SIGNAL 19
void DaemonAdaptor::onSetMultipleActionsBehaviour(const MultipleActionsBehaviour & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void DaemonAdaptor::onGetMultipleActionsBehaviour(MultipleActionsBehaviour & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void DaemonAdaptor::onGetAllActionIds(QList<qulonglong> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void DaemonAdaptor::onGetActionById(QPair<bool,GeneralActionInfo> & _t1, qulonglong _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1, _t2);
}

// SIGNAL 23
void DaemonAdaptor::onGetAllActions(QMap<qulonglong,GeneralActionInfo> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1);
}

// SIGNAL 24
void DaemonAdaptor::onGetClientActionInfoById(QPair<bool,ClientActionInfo> & _t1, qulonglong _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1, _t2);
}

// SIGNAL 25
void DaemonAdaptor::onGetMethodActionInfoById(QPair<bool,MethodActionInfo> & _t1, qulonglong _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1, _t2);
}

// SIGNAL 26
void DaemonAdaptor::onGetCommandActionInfoById(QPair<bool,CommandActionInfo> & _t1, qulonglong _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 26, nullptr, _t1, _t2);
}

// SIGNAL 27
void DaemonAdaptor::onGrabShortcut(uint _t1, QString & _t2, bool & _t3, bool & _t4, bool & _t5, const QDBusMessage & _t6)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 27, nullptr, _t1, _t2, _t3, _t4, _t5, _t6);
}

// SIGNAL 28
void DaemonAdaptor::onCancelShortcutGrab()
{
    QMetaObject::activate(this, &staticMetaObject, 28, nullptr);
}

// SIGNAL 29
void DaemonAdaptor::onQuit()
{
    QMetaObject::activate(this, &staticMetaObject, 29, nullptr);
}
QT_WARNING_POP
