/****************************************************************************
** Meta object code from reading C++ file 'actions.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../lxqt-globalkeys-2.3.0/config/actions.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'actions.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.10.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7ActionsE_t {};
} // unnamed namespace

template <> constexpr inline auto Actions::qt_create_metaobjectdata<qt_meta_tag_ZN7ActionsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Actions",
        "daemonDisappeared",
        "",
        "daemonAppeared",
        "actionAdded",
        "id",
        "actionEnabled",
        "enabled",
        "actionModified",
        "actionsSwapped",
        "id1",
        "id2",
        "actionRemoved",
        "multipleActionsBehaviourChanged",
        "MultipleActionsBehaviour",
        "behaviour",
        "shortcutGrabbed",
        "grabShortcutFailed",
        "grabShortcutCancelled",
        "grabShortcutTimedout",
        "delayedInit",
        "on_daemonDisappeared",
        "on_daemonAppeared",
        "on_actionAdded",
        "on_actionEnabled",
        "on_clientActionSenderChanged",
        "sender",
        "on_actionModified",
        "on_actionShortcutChanged",
        "on_actionsSwapped",
        "on_actionRemoved",
        "on_multipleActionsBehaviourChanged",
        "grabShortcutFinished",
        "QDBusPendingCallWatcher*",
        "call"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'daemonDisappeared'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'daemonAppeared'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'actionAdded'
        QtMocHelpers::SignalData<void(qulonglong)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 5 },
        }}),
        // Signal 'actionEnabled'
        QtMocHelpers::SignalData<void(qulonglong, bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 5 }, { QMetaType::Bool, 7 },
        }}),
        // Signal 'actionModified'
        QtMocHelpers::SignalData<void(qulonglong)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 5 },
        }}),
        // Signal 'actionsSwapped'
        QtMocHelpers::SignalData<void(qulonglong, qulonglong)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 10 }, { QMetaType::ULongLong, 11 },
        }}),
        // Signal 'actionRemoved'
        QtMocHelpers::SignalData<void(qulonglong)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 5 },
        }}),
        // Signal 'multipleActionsBehaviourChanged'
        QtMocHelpers::SignalData<void(MultipleActionsBehaviour)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Signal 'shortcutGrabbed'
        QtMocHelpers::SignalData<void(const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'grabShortcutFailed'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'grabShortcutCancelled'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'grabShortcutTimedout'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'delayedInit'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_daemonDisappeared'
        QtMocHelpers::SlotData<void(const QString &)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'on_daemonAppeared'
        QtMocHelpers::SlotData<void(const QString &)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'on_actionAdded'
        QtMocHelpers::SlotData<void(qulonglong)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::ULongLong, 5 },
        }}),
        // Slot 'on_actionEnabled'
        QtMocHelpers::SlotData<void(qulonglong, bool)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::ULongLong, 5 }, { QMetaType::Bool, 7 },
        }}),
        // Slot 'on_clientActionSenderChanged'
        QtMocHelpers::SlotData<void(qulonglong, const QString &)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::ULongLong, 5 }, { QMetaType::QString, 26 },
        }}),
        // Slot 'on_actionModified'
        QtMocHelpers::SlotData<void(qulonglong)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::ULongLong, 5 },
        }}),
        // Slot 'on_actionShortcutChanged'
        QtMocHelpers::SlotData<void(qulonglong)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::ULongLong, 5 },
        }}),
        // Slot 'on_actionsSwapped'
        QtMocHelpers::SlotData<void(qulonglong, qulonglong)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::ULongLong, 10 }, { QMetaType::ULongLong, 11 },
        }}),
        // Slot 'on_actionRemoved'
        QtMocHelpers::SlotData<void(qulonglong)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::ULongLong, 5 },
        }}),
        // Slot 'on_multipleActionsBehaviourChanged'
        QtMocHelpers::SlotData<void(uint)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 15 },
        }}),
        // Slot 'grabShortcutFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 33, 34 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Actions, qt_meta_tag_ZN7ActionsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Actions::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7ActionsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7ActionsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7ActionsE_t>.metaTypes,
    nullptr
} };

void Actions::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Actions *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->daemonDisappeared(); break;
        case 1: _t->daemonAppeared(); break;
        case 2: _t->actionAdded((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 3: _t->actionEnabled((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 4: _t->actionModified((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 5: _t->actionsSwapped((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2]))); break;
        case 6: _t->actionRemoved((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 7: _t->multipleActionsBehaviourChanged((*reinterpret_cast<std::add_pointer_t<MultipleActionsBehaviour>>(_a[1]))); break;
        case 8: _t->shortcutGrabbed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->grabShortcutFailed(); break;
        case 10: _t->grabShortcutCancelled(); break;
        case 11: _t->grabShortcutTimedout(); break;
        case 12: _t->delayedInit(); break;
        case 13: _t->on_daemonDisappeared((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->on_daemonAppeared((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->on_actionAdded((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 16: _t->on_actionEnabled((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 17: _t->on_clientActionSenderChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 18: _t->on_actionModified((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 19: _t->on_actionShortcutChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 20: _t->on_actionsSwapped((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2]))); break;
        case 21: _t->on_actionRemoved((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 22: _t->on_multipleActionsBehaviourChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 23: _t->grabShortcutFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Actions::*)()>(_a, &Actions::daemonDisappeared, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Actions::*)()>(_a, &Actions::daemonAppeared, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Actions::*)(qulonglong )>(_a, &Actions::actionAdded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Actions::*)(qulonglong , bool )>(_a, &Actions::actionEnabled, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Actions::*)(qulonglong )>(_a, &Actions::actionModified, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Actions::*)(qulonglong , qulonglong )>(_a, &Actions::actionsSwapped, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Actions::*)(qulonglong )>(_a, &Actions::actionRemoved, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Actions::*)(MultipleActionsBehaviour )>(_a, &Actions::multipleActionsBehaviourChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Actions::*)(const QString & )>(_a, &Actions::shortcutGrabbed, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Actions::*)()>(_a, &Actions::grabShortcutFailed, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Actions::*)()>(_a, &Actions::grabShortcutCancelled, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Actions::*)()>(_a, &Actions::grabShortcutTimedout, 11))
            return;
    }
}

const QMetaObject *Actions::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Actions::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7ActionsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Actions::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 24;
    }
    return _id;
}

// SIGNAL 0
void Actions::daemonDisappeared()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Actions::daemonAppeared()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Actions::actionAdded(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Actions::actionEnabled(qulonglong _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void Actions::actionModified(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Actions::actionsSwapped(qulonglong _t1, qulonglong _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void Actions::actionRemoved(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Actions::multipleActionsBehaviourChanged(MultipleActionsBehaviour _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Actions::shortcutGrabbed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Actions::grabShortcutFailed()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Actions::grabShortcutCancelled()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Actions::grabShortcutTimedout()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
